Documentation
¶
Index ¶
- Constants
- type AbstractRuntimeMC
- type Client
- func (c *Client) GetRuntimeMC(request *GetRuntimeMCRequest) (response *GetRuntimeMCResponse, err error)
- func (c *Client) GetRuntimeMCWithContext(ctx context.Context, request *GetRuntimeMCRequest) (response *GetRuntimeMCResponse, err error)
- func (c *Client) GetRuntimeResourceMonitorMetricMC(request *GetRuntimeResourceMonitorMetricMCRequest) (response *GetRuntimeResourceMonitorMetricMCResponse, err error)
- func (c *Client) GetRuntimeResourceMonitorMetricMCWithContext(ctx context.Context, request *GetRuntimeResourceMonitorMetricMCRequest) (response *GetRuntimeResourceMonitorMetricMCResponse, err error)
- func (c *Client) ListDeployableRuntimesMC(request *ListDeployableRuntimesMCRequest) (response *ListDeployableRuntimesMCResponse, err error)
- func (c *Client) ListDeployableRuntimesMCWithContext(ctx context.Context, request *ListDeployableRuntimesMCRequest) (response *ListDeployableRuntimesMCResponse, err error)
- func (c *Client) ListRuntimeDeployedInstancesMC(request *ListRuntimeDeployedInstancesMCRequest) (response *ListRuntimeDeployedInstancesMCResponse, err error)
- func (c *Client) ListRuntimeDeployedInstancesMCWithContext(ctx context.Context, request *ListRuntimeDeployedInstancesMCRequest) (response *ListRuntimeDeployedInstancesMCResponse, err error)
- func (c *Client) ListRuntimesMC(request *ListRuntimesMCRequest) (response *ListRuntimesMCResponse, err error)
- func (c *Client) ListRuntimesMCWithContext(ctx context.Context, request *ListRuntimesMCRequest) (response *ListRuntimesMCResponse, err error)
- type GetRuntimeMCRequest
- type GetRuntimeMCRequestParams
- type GetRuntimeMCResponse
- type GetRuntimeMCResponseParams
- type GetRuntimeResourceMonitorMetricMCRequest
- type GetRuntimeResourceMonitorMetricMCRequestParams
- type GetRuntimeResourceMonitorMetricMCResponse
- type GetRuntimeResourceMonitorMetricMCResponseParams
- type ListDeployableRuntimesMCRequest
- type ListDeployableRuntimesMCRequestParams
- type ListDeployableRuntimesMCResponse
- type ListDeployableRuntimesMCResponseParams
- type ListRuntimeDeployedInstancesMCRequest
- type ListRuntimeDeployedInstancesMCRequestParams
- type ListRuntimeDeployedInstancesMCResponse
- type ListRuntimeDeployedInstancesMCResponseParams
- type ListRuntimesMCRequest
- type ListRuntimesMCRequestParams
- type ListRuntimesMCResponse
- type ListRuntimesMCResponseParams
- type MetricValueMC
- type RuntimeDeployedInstanceMC
- type RuntimeExtensionMC
- type RuntimeMC
Constants ¶
const ( // 操作失败。 FAILEDOPERATION = "FailedOperation" // 鉴权失败。 FAILEDOPERATION_AUTHENTICATIONFAILED = "FailedOperation.AuthenticationFailed" // 接口处理超时。 FAILEDOPERATION_INNERLOGICTIMEOUT = "FailedOperation.InnerLogicTimeOut" // 依赖服务错误。 FAILEDOPERATION_METACOMPILERERROR = "FailedOperation.MetaCompilerError" // 不支持的操作类型。 FAILEDOPERATION_UNSUPPORTEDOPERATIONTYPE = "FailedOperation.UnSupportedOperationType" // 检查运行时失败。 INTERNALERROR_CHECKRUNTIMEFAILED = "InternalError.CheckRuntimeFailed" // 获取运行时应用数量失败。 INTERNALERROR_COUNTRUNTIMEINSTANCESFAILED = "InternalError.CountRuntimeInstancesFailed" // 数据库内部错误。 INTERNALERROR_DATABASEERROR = "InternalError.DatabaseError" // 获取运行时应用列表失败。 INTERNALERROR_LISTRUNTIMEINSTANCESFAILED = "InternalError.ListRuntimeInstancesFailed" // 获取运行时列表失败。 INTERNALERROR_LISTRUNTIMESFAILED = "InternalError.ListRuntimesFailed" // 依赖模块metacompiler错误。 INTERNALERROR_METACOMPILERERROR = "InternalError.MetaCompilerError" // rpc调用异常。 INTERNALERROR_RPCPILOTSERVERERROR = "InternalError.RpcPilotServerError" // 指标查询参数错误。 INVALIDPARAMETERVALUE_INVALIDRUNTIMEMETRICSEARCHCONDITION = "InvalidParameterValue.InvalidRuntimeMetricSearchCondition" // 共享运行时不支持此操作。 INVALIDPARAMETERVALUE_NOTSUPPORTEDACTIONFORPUBLICRUNTIME = "InvalidParameterValue.NotSupportedActionForPublicRuntime" // 不支持的Zone。 INVALIDPARAMETERVALUE_PILOTZONENOTSUPPORTED = "InvalidParameterValue.PilotZoneNotSupported" // 运行时已删除。 INVALIDPARAMETERVALUE_RUNTIMEALREADYDELETED = "InvalidParameterValue.RuntimeAlreadyDeleted" // 运行时不存在。 INVALIDPARAMETERVALUE_RUNTIMEIDNOTEXIST = "InvalidParameterValue.RuntimeIdNotExist" // 当前指标不支持查询百分比。 INVALIDPARAMETERVALUE_RUNTIMEMETRICRATENOTSUPPORT = "InvalidParameterValue.RuntimeMetricRateNotSupport" // 运行时命名空间不合法。 INVALIDPARAMETERVALUE_RUNTIMENAMESPACEINVALID = "InvalidParameterValue.RuntimeNamespaceInvalid" // 运行时地域不存在。 INVALIDPARAMETERVALUE_RUNTIMEZONENOTEXISTED = "InvalidParameterValue.RuntimeZoneNotExisted" // 资源不可用。 RESOURCEUNAVAILABLE = "ResourceUnavailable" )
const APIVersion = "2021-06-01"
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AbstractRuntimeMC ¶
type AbstractRuntimeMC struct {
// 环境id
RuntimeId *int64 `json:"RuntimeId,omitempty" name:"RuntimeId"`
// 环境名称,用户输入,同一uin内唯一
DisplayName *string `json:"DisplayName,omitempty" name:"DisplayName"`
// 环境类型:0: sandbox, 1:shared, 2:private
Type *int64 `json:"Type,omitempty" name:"Type"`
// 环境所在地域,tianjin,beijiing,guangzhou等
Zone *string `json:"Zone,omitempty" name:"Zone"`
// 环境所在地域,tianjin,beijiing,guangzhou等(同Zone)
Area *string `json:"Area,omitempty" name:"Area"`
// 环境应用listener地址后缀
Addr *string `json:"Addr,omitempty" name:"Addr"`
// 环境状态
Status *int64 `json:"Status,omitempty" name:"Status"`
// 环境过期时间
ExpiredAt *int64 `json:"ExpiredAt,omitempty" name:"ExpiredAt"`
// 环境运行类型:0:运行时类型、1:api类型
RuntimeClass *int64 `json:"RuntimeClass,omitempty" name:"RuntimeClass"`
// 是否已在当前环境发布
// 注意:此字段可能返回 null,表示取不到有效值。
Deployed *bool `json:"Deployed,omitempty" name:"Deployed"`
}
type Client ¶
func NewClient ¶
func NewClient(credential common.CredentialIface, region string, clientProfile *profile.ClientProfile) (client *Client, err error)
func NewClientWithSecretId ¶
Deprecated
func (*Client) GetRuntimeMC ¶
func (c *Client) GetRuntimeMC(request *GetRuntimeMCRequest) (response *GetRuntimeMCResponse, err error)
GetRuntimeMC 获取运行时详情
可能返回的错误码:
FAILEDOPERATION = "FailedOperation" FAILEDOPERATION_AUTHENTICATIONFAILED = "FailedOperation.AuthenticationFailed" INTERNALERROR_CHECKRUNTIMEFAILED = "InternalError.CheckRuntimeFailed" INTERNALERROR_COUNTRUNTIMEINSTANCESFAILED = "InternalError.CountRuntimeInstancesFailed" INTERNALERROR_DATABASEERROR = "InternalError.DatabaseError" INTERNALERROR_METACOMPILERERROR = "InternalError.MetaCompilerError" INTERNALERROR_RPCPILOTSERVERERROR = "InternalError.RpcPilotServerError" INVALIDPARAMETERVALUE_PILOTZONENOTSUPPORTED = "InvalidParameterValue.PilotZoneNotSupported" INVALIDPARAMETERVALUE_RUNTIMEALREADYDELETED = "InvalidParameterValue.RuntimeAlreadyDeleted" INVALIDPARAMETERVALUE_RUNTIMEIDNOTEXIST = "InvalidParameterValue.RuntimeIdNotExist" INVALIDPARAMETERVALUE_RUNTIMENAMESPACEINVALID = "InvalidParameterValue.RuntimeNamespaceInvalid" INVALIDPARAMETERVALUE_RUNTIMEZONENOTEXISTED = "InvalidParameterValue.RuntimeZoneNotExisted"
func (*Client) GetRuntimeMCWithContext ¶ added in v1.0.324
func (c *Client) GetRuntimeMCWithContext(ctx context.Context, request *GetRuntimeMCRequest) (response *GetRuntimeMCResponse, err error)
GetRuntimeMC 获取运行时详情
可能返回的错误码:
FAILEDOPERATION = "FailedOperation" FAILEDOPERATION_AUTHENTICATIONFAILED = "FailedOperation.AuthenticationFailed" INTERNALERROR_CHECKRUNTIMEFAILED = "InternalError.CheckRuntimeFailed" INTERNALERROR_COUNTRUNTIMEINSTANCESFAILED = "InternalError.CountRuntimeInstancesFailed" INTERNALERROR_DATABASEERROR = "InternalError.DatabaseError" INTERNALERROR_METACOMPILERERROR = "InternalError.MetaCompilerError" INTERNALERROR_RPCPILOTSERVERERROR = "InternalError.RpcPilotServerError" INVALIDPARAMETERVALUE_PILOTZONENOTSUPPORTED = "InvalidParameterValue.PilotZoneNotSupported" INVALIDPARAMETERVALUE_RUNTIMEALREADYDELETED = "InvalidParameterValue.RuntimeAlreadyDeleted" INVALIDPARAMETERVALUE_RUNTIMEIDNOTEXIST = "InvalidParameterValue.RuntimeIdNotExist" INVALIDPARAMETERVALUE_RUNTIMENAMESPACEINVALID = "InvalidParameterValue.RuntimeNamespaceInvalid" INVALIDPARAMETERVALUE_RUNTIMEZONENOTEXISTED = "InvalidParameterValue.RuntimeZoneNotExisted"
func (*Client) GetRuntimeResourceMonitorMetricMC ¶
func (c *Client) GetRuntimeResourceMonitorMetricMC(request *GetRuntimeResourceMonitorMetricMCRequest) (response *GetRuntimeResourceMonitorMetricMCResponse, err error)
GetRuntimeResourceMonitorMetricMC 获取运行时资源监控详情,cpu,memory,bandwidth
可能返回的错误码:
FAILEDOPERATION = "FailedOperation" FAILEDOPERATION_INNERLOGICTIMEOUT = "FailedOperation.InnerLogicTimeOut" INTERNALERROR_CHECKRUNTIMEFAILED = "InternalError.CheckRuntimeFailed" INVALIDPARAMETERVALUE_INVALIDRUNTIMEMETRICSEARCHCONDITION = "InvalidParameterValue.InvalidRuntimeMetricSearchCondition" INVALIDPARAMETERVALUE_NOTSUPPORTEDACTIONFORPUBLICRUNTIME = "InvalidParameterValue.NotSupportedActionForPublicRuntime" INVALIDPARAMETERVALUE_PILOTZONENOTSUPPORTED = "InvalidParameterValue.PilotZoneNotSupported" INVALIDPARAMETERVALUE_RUNTIMEALREADYDELETED = "InvalidParameterValue.RuntimeAlreadyDeleted" INVALIDPARAMETERVALUE_RUNTIMEIDNOTEXIST = "InvalidParameterValue.RuntimeIdNotExist" INVALIDPARAMETERVALUE_RUNTIMEMETRICRATENOTSUPPORT = "InvalidParameterValue.RuntimeMetricRateNotSupport" INVALIDPARAMETERVALUE_RUNTIMENAMESPACEINVALID = "InvalidParameterValue.RuntimeNamespaceInvalid" INVALIDPARAMETERVALUE_RUNTIMEZONENOTEXISTED = "InvalidParameterValue.RuntimeZoneNotExisted"
func (*Client) GetRuntimeResourceMonitorMetricMCWithContext ¶ added in v1.0.324
func (c *Client) GetRuntimeResourceMonitorMetricMCWithContext(ctx context.Context, request *GetRuntimeResourceMonitorMetricMCRequest) (response *GetRuntimeResourceMonitorMetricMCResponse, err error)
GetRuntimeResourceMonitorMetricMC 获取运行时资源监控详情,cpu,memory,bandwidth
可能返回的错误码:
FAILEDOPERATION = "FailedOperation" FAILEDOPERATION_INNERLOGICTIMEOUT = "FailedOperation.InnerLogicTimeOut" INTERNALERROR_CHECKRUNTIMEFAILED = "InternalError.CheckRuntimeFailed" INVALIDPARAMETERVALUE_INVALIDRUNTIMEMETRICSEARCHCONDITION = "InvalidParameterValue.InvalidRuntimeMetricSearchCondition" INVALIDPARAMETERVALUE_NOTSUPPORTEDACTIONFORPUBLICRUNTIME = "InvalidParameterValue.NotSupportedActionForPublicRuntime" INVALIDPARAMETERVALUE_PILOTZONENOTSUPPORTED = "InvalidParameterValue.PilotZoneNotSupported" INVALIDPARAMETERVALUE_RUNTIMEALREADYDELETED = "InvalidParameterValue.RuntimeAlreadyDeleted" INVALIDPARAMETERVALUE_RUNTIMEIDNOTEXIST = "InvalidParameterValue.RuntimeIdNotExist" INVALIDPARAMETERVALUE_RUNTIMEMETRICRATENOTSUPPORT = "InvalidParameterValue.RuntimeMetricRateNotSupport" INVALIDPARAMETERVALUE_RUNTIMENAMESPACEINVALID = "InvalidParameterValue.RuntimeNamespaceInvalid" INVALIDPARAMETERVALUE_RUNTIMEZONENOTEXISTED = "InvalidParameterValue.RuntimeZoneNotExisted"
func (*Client) ListDeployableRuntimesMC ¶
func (c *Client) ListDeployableRuntimesMC(request *ListDeployableRuntimesMCRequest) (response *ListDeployableRuntimesMCResponse, err error)
ListDeployableRuntimesMC 返回用户可用的运行时列表,发布应用时返回的运行时环境,仅shared和private运行时,无sandbox运行时,并且只有running/scaling状态的
可能返回的错误码:
FAILEDOPERATION_AUTHENTICATIONFAILED = "FailedOperation.AuthenticationFailed" FAILEDOPERATION_UNSUPPORTEDOPERATIONTYPE = "FailedOperation.UnSupportedOperationType" INTERNALERROR_DATABASEERROR = "InternalError.DatabaseError" INTERNALERROR_RPCPILOTSERVERERROR = "InternalError.RpcPilotServerError" INVALIDPARAMETERVALUE_PILOTZONENOTSUPPORTED = "InvalidParameterValue.PilotZoneNotSupported"
func (*Client) ListDeployableRuntimesMCWithContext ¶ added in v1.0.324
func (c *Client) ListDeployableRuntimesMCWithContext(ctx context.Context, request *ListDeployableRuntimesMCRequest) (response *ListDeployableRuntimesMCResponse, err error)
ListDeployableRuntimesMC 返回用户可用的运行时列表,发布应用时返回的运行时环境,仅shared和private运行时,无sandbox运行时,并且只有running/scaling状态的
可能返回的错误码:
FAILEDOPERATION_AUTHENTICATIONFAILED = "FailedOperation.AuthenticationFailed" FAILEDOPERATION_UNSUPPORTEDOPERATIONTYPE = "FailedOperation.UnSupportedOperationType" INTERNALERROR_DATABASEERROR = "InternalError.DatabaseError" INTERNALERROR_RPCPILOTSERVERERROR = "InternalError.RpcPilotServerError" INVALIDPARAMETERVALUE_PILOTZONENOTSUPPORTED = "InvalidParameterValue.PilotZoneNotSupported"
func (*Client) ListRuntimeDeployedInstancesMC ¶
func (c *Client) ListRuntimeDeployedInstancesMC(request *ListRuntimeDeployedInstancesMCRequest) (response *ListRuntimeDeployedInstancesMCResponse, err error)
ListRuntimeDeployedInstancesMC 获取运行时部署的应用实例列表
可能返回的错误码:
INTERNALERROR_CHECKRUNTIMEFAILED = "InternalError.CheckRuntimeFailed" INTERNALERROR_DATABASEERROR = "InternalError.DatabaseError" INTERNALERROR_LISTRUNTIMEINSTANCESFAILED = "InternalError.ListRuntimeInstancesFailed" INTERNALERROR_METACOMPILERERROR = "InternalError.MetaCompilerError" INTERNALERROR_RPCPILOTSERVERERROR = "InternalError.RpcPilotServerError" INVALIDPARAMETERVALUE_PILOTZONENOTSUPPORTED = "InvalidParameterValue.PilotZoneNotSupported" INVALIDPARAMETERVALUE_RUNTIMEALREADYDELETED = "InvalidParameterValue.RuntimeAlreadyDeleted" INVALIDPARAMETERVALUE_RUNTIMEIDNOTEXIST = "InvalidParameterValue.RuntimeIdNotExist" INVALIDPARAMETERVALUE_RUNTIMEZONENOTEXISTED = "InvalidParameterValue.RuntimeZoneNotExisted"
func (*Client) ListRuntimeDeployedInstancesMCWithContext ¶ added in v1.0.324
func (c *Client) ListRuntimeDeployedInstancesMCWithContext(ctx context.Context, request *ListRuntimeDeployedInstancesMCRequest) (response *ListRuntimeDeployedInstancesMCResponse, err error)
ListRuntimeDeployedInstancesMC 获取运行时部署的应用实例列表
可能返回的错误码:
INTERNALERROR_CHECKRUNTIMEFAILED = "InternalError.CheckRuntimeFailed" INTERNALERROR_DATABASEERROR = "InternalError.DatabaseError" INTERNALERROR_LISTRUNTIMEINSTANCESFAILED = "InternalError.ListRuntimeInstancesFailed" INTERNALERROR_METACOMPILERERROR = "InternalError.MetaCompilerError" INTERNALERROR_RPCPILOTSERVERERROR = "InternalError.RpcPilotServerError" INVALIDPARAMETERVALUE_PILOTZONENOTSUPPORTED = "InvalidParameterValue.PilotZoneNotSupported" INVALIDPARAMETERVALUE_RUNTIMEALREADYDELETED = "InvalidParameterValue.RuntimeAlreadyDeleted" INVALIDPARAMETERVALUE_RUNTIMEIDNOTEXIST = "InvalidParameterValue.RuntimeIdNotExist" INVALIDPARAMETERVALUE_RUNTIMEZONENOTEXISTED = "InvalidParameterValue.RuntimeZoneNotExisted"
func (*Client) ListRuntimesMC ¶
func (c *Client) ListRuntimesMC(request *ListRuntimesMCRequest) (response *ListRuntimesMCResponse, err error)
ListRuntimesMC 返回用户的运行时列表,运行时管理主页使用,包含沙箱、共享运行时及独立运行时环境,不包含已经删除的运行时
可能返回的错误码:
FAILEDOPERATION = "FailedOperation" FAILEDOPERATION_AUTHENTICATIONFAILED = "FailedOperation.AuthenticationFailed" FAILEDOPERATION_METACOMPILERERROR = "FailedOperation.MetaCompilerError" FAILEDOPERATION_UNSUPPORTEDOPERATIONTYPE = "FailedOperation.UnSupportedOperationType" INTERNALERROR_DATABASEERROR = "InternalError.DatabaseError" INTERNALERROR_LISTRUNTIMESFAILED = "InternalError.ListRuntimesFailed" INTERNALERROR_METACOMPILERERROR = "InternalError.MetaCompilerError" INTERNALERROR_RPCPILOTSERVERERROR = "InternalError.RpcPilotServerError" INVALIDPARAMETERVALUE_PILOTZONENOTSUPPORTED = "InvalidParameterValue.PilotZoneNotSupported" RESOURCEUNAVAILABLE = "ResourceUnavailable"
func (*Client) ListRuntimesMCWithContext ¶ added in v1.0.324
func (c *Client) ListRuntimesMCWithContext(ctx context.Context, request *ListRuntimesMCRequest) (response *ListRuntimesMCResponse, err error)
ListRuntimesMC 返回用户的运行时列表,运行时管理主页使用,包含沙箱、共享运行时及独立运行时环境,不包含已经删除的运行时
可能返回的错误码:
FAILEDOPERATION = "FailedOperation" FAILEDOPERATION_AUTHENTICATIONFAILED = "FailedOperation.AuthenticationFailed" FAILEDOPERATION_METACOMPILERERROR = "FailedOperation.MetaCompilerError" FAILEDOPERATION_UNSUPPORTEDOPERATIONTYPE = "FailedOperation.UnSupportedOperationType" INTERNALERROR_DATABASEERROR = "InternalError.DatabaseError" INTERNALERROR_LISTRUNTIMESFAILED = "InternalError.ListRuntimesFailed" INTERNALERROR_METACOMPILERERROR = "InternalError.MetaCompilerError" INTERNALERROR_RPCPILOTSERVERERROR = "InternalError.RpcPilotServerError" INVALIDPARAMETERVALUE_PILOTZONENOTSUPPORTED = "InvalidParameterValue.PilotZoneNotSupported" RESOURCEUNAVAILABLE = "ResourceUnavailable"
type GetRuntimeMCRequest ¶
type GetRuntimeMCRequest struct {
*tchttp.BaseRequest
// 环境id
RuntimeId *int64 `json:"RuntimeId,omitempty" name:"RuntimeId"`
// 环境地域
Zone *string `json:"Zone,omitempty" name:"Zone"`
// 环境运行类型:0:运行时类型、1:api类型
RuntimeClass *int64 `json:"RuntimeClass,omitempty" name:"RuntimeClass"`
}
func NewGetRuntimeMCRequest ¶
func NewGetRuntimeMCRequest() (request *GetRuntimeMCRequest)
func (*GetRuntimeMCRequest) FromJsonString ¶
func (r *GetRuntimeMCRequest) FromJsonString(s string) error
FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check
func (*GetRuntimeMCRequest) ToJsonString ¶
func (r *GetRuntimeMCRequest) ToJsonString() string
type GetRuntimeMCRequestParams ¶ added in v1.0.426
type GetRuntimeMCRequestParams struct {
// 环境id
RuntimeId *int64 `json:"RuntimeId,omitempty" name:"RuntimeId"`
// 环境地域
Zone *string `json:"Zone,omitempty" name:"Zone"`
// 环境运行类型:0:运行时类型、1:api类型
RuntimeClass *int64 `json:"RuntimeClass,omitempty" name:"RuntimeClass"`
}
Predefined struct for user
type GetRuntimeMCResponse ¶
type GetRuntimeMCResponse struct {
*tchttp.BaseResponse
Response *GetRuntimeMCResponseParams `json:"Response"`
}
func NewGetRuntimeMCResponse ¶
func NewGetRuntimeMCResponse() (response *GetRuntimeMCResponse)
func (*GetRuntimeMCResponse) FromJsonString ¶
func (r *GetRuntimeMCResponse) FromJsonString(s string) error
FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check
func (*GetRuntimeMCResponse) ToJsonString ¶
func (r *GetRuntimeMCResponse) ToJsonString() string
type GetRuntimeMCResponseParams ¶ added in v1.0.426
type GetRuntimeMCResponseParams struct {
// 运行时详情
Runtime *RuntimeMC `json:"Runtime,omitempty" name:"Runtime"`
// 唯一请求 ID,每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
RequestId *string `json:"RequestId,omitempty" name:"RequestId"`
}
Predefined struct for user
type GetRuntimeResourceMonitorMetricMCRequest ¶
type GetRuntimeResourceMonitorMetricMCRequest struct {
*tchttp.BaseRequest
// 运行时id
RuntimeId *int64 `json:"RuntimeId,omitempty" name:"RuntimeId"`
// 起始时间
StartTime *int64 `json:"StartTime,omitempty" name:"StartTime"`
// 结束时间
EndTime *int64 `json:"EndTime,omitempty" name:"EndTime"`
// 指标类型:0:CPU, 1:MemUsageBytes, 2:K8sWorkloadNetworkReceiveBytesBw, 3:K8sWorkloadNetworkTransmitBytesBw
MetricType *int64 `json:"MetricType,omitempty" name:"MetricType"`
// 是否返回百分比数值,仅支持CPU,Memory
RateType *bool `json:"RateType,omitempty" name:"RateType"`
// 采样粒度:60(s), 300(s), 3600(s), 86400(s)
Interval *int64 `json:"Interval,omitempty" name:"Interval"`
// 环境运行类型:0:运行时类型、1:api类型
RuntimeClass *int64 `json:"RuntimeClass,omitempty" name:"RuntimeClass"`
}
func NewGetRuntimeResourceMonitorMetricMCRequest ¶
func NewGetRuntimeResourceMonitorMetricMCRequest() (request *GetRuntimeResourceMonitorMetricMCRequest)
func (*GetRuntimeResourceMonitorMetricMCRequest) FromJsonString ¶
func (r *GetRuntimeResourceMonitorMetricMCRequest) FromJsonString(s string) error
FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check
func (*GetRuntimeResourceMonitorMetricMCRequest) ToJsonString ¶
func (r *GetRuntimeResourceMonitorMetricMCRequest) ToJsonString() string
type GetRuntimeResourceMonitorMetricMCRequestParams ¶ added in v1.0.426
type GetRuntimeResourceMonitorMetricMCRequestParams struct {
// 运行时id
RuntimeId *int64 `json:"RuntimeId,omitempty" name:"RuntimeId"`
// 起始时间
StartTime *int64 `json:"StartTime,omitempty" name:"StartTime"`
// 结束时间
EndTime *int64 `json:"EndTime,omitempty" name:"EndTime"`
// 指标类型:0:CPU, 1:MemUsageBytes, 2:K8sWorkloadNetworkReceiveBytesBw, 3:K8sWorkloadNetworkTransmitBytesBw
MetricType *int64 `json:"MetricType,omitempty" name:"MetricType"`
// 是否返回百分比数值,仅支持CPU,Memory
RateType *bool `json:"RateType,omitempty" name:"RateType"`
// 采样粒度:60(s), 300(s), 3600(s), 86400(s)
Interval *int64 `json:"Interval,omitempty" name:"Interval"`
// 环境运行类型:0:运行时类型、1:api类型
RuntimeClass *int64 `json:"RuntimeClass,omitempty" name:"RuntimeClass"`
}
Predefined struct for user
type GetRuntimeResourceMonitorMetricMCResponse ¶
type GetRuntimeResourceMonitorMetricMCResponse struct {
*tchttp.BaseResponse
Response *GetRuntimeResourceMonitorMetricMCResponseParams `json:"Response"`
}
func NewGetRuntimeResourceMonitorMetricMCResponse ¶
func NewGetRuntimeResourceMonitorMetricMCResponse() (response *GetRuntimeResourceMonitorMetricMCResponse)
func (*GetRuntimeResourceMonitorMetricMCResponse) FromJsonString ¶
func (r *GetRuntimeResourceMonitorMetricMCResponse) FromJsonString(s string) error
FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check
func (*GetRuntimeResourceMonitorMetricMCResponse) ToJsonString ¶
func (r *GetRuntimeResourceMonitorMetricMCResponse) ToJsonString() string
type GetRuntimeResourceMonitorMetricMCResponseParams ¶ added in v1.0.426
type GetRuntimeResourceMonitorMetricMCResponseParams struct {
// 指标名称,K8sWorkloadCpuCoreUsed,K8sWorkloadMemUsageBytes,K8sWorkloadNetworkReceiveBytesBw,K8sWorkloadNetworkTransmitBytesBw
MetricType *string `json:"MetricType,omitempty" name:"MetricType"`
// metric数值列表
Values []*MetricValueMC `json:"Values,omitempty" name:"Values"`
// 唯一请求 ID,每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
RequestId *string `json:"RequestId,omitempty" name:"RequestId"`
}
Predefined struct for user
type ListDeployableRuntimesMCRequest ¶
type ListDeployableRuntimesMCRequest struct {
*tchttp.BaseRequest
}
func NewListDeployableRuntimesMCRequest ¶
func NewListDeployableRuntimesMCRequest() (request *ListDeployableRuntimesMCRequest)
func (*ListDeployableRuntimesMCRequest) FromJsonString ¶
func (r *ListDeployableRuntimesMCRequest) FromJsonString(s string) error
FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check
func (*ListDeployableRuntimesMCRequest) ToJsonString ¶
func (r *ListDeployableRuntimesMCRequest) ToJsonString() string
type ListDeployableRuntimesMCRequestParams ¶ added in v1.0.426
type ListDeployableRuntimesMCRequestParams struct {
}
Predefined struct for user
type ListDeployableRuntimesMCResponse ¶
type ListDeployableRuntimesMCResponse struct {
*tchttp.BaseResponse
Response *ListDeployableRuntimesMCResponseParams `json:"Response"`
}
func NewListDeployableRuntimesMCResponse ¶
func NewListDeployableRuntimesMCResponse() (response *ListDeployableRuntimesMCResponse)
func (*ListDeployableRuntimesMCResponse) FromJsonString ¶
func (r *ListDeployableRuntimesMCResponse) FromJsonString(s string) error
FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check
func (*ListDeployableRuntimesMCResponse) ToJsonString ¶
func (r *ListDeployableRuntimesMCResponse) ToJsonString() string
type ListDeployableRuntimesMCResponseParams ¶ added in v1.0.426
type ListDeployableRuntimesMCResponseParams struct {
// 运行时列表
Runtimes []*AbstractRuntimeMC `json:"Runtimes,omitempty" name:"Runtimes"`
// 唯一请求 ID,每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
RequestId *string `json:"RequestId,omitempty" name:"RequestId"`
}
Predefined struct for user
type ListRuntimeDeployedInstancesMCRequest ¶
type ListRuntimeDeployedInstancesMCRequest struct {
*tchttp.BaseRequest
// 运行时id
RuntimeId *int64 `json:"RuntimeId,omitempty" name:"RuntimeId"`
// 最大请求数量
Limit *int64 `json:"Limit,omitempty" name:"Limit"`
// 请求偏移量
Offset *int64 `json:"Offset,omitempty" name:"Offset"`
// 排序类型:1:创建时间排序, 2:更新时间排序(默认)
SortType *int64 `json:"SortType,omitempty" name:"SortType"`
// 排序方式:asc,desc(默认)
Sort *string `json:"Sort,omitempty" name:"Sort"`
// 运行时地域
Zone *string `json:"Zone,omitempty" name:"Zone"`
// 1:3.0版本新控制台传1;否则传0
ApiVersion *int64 `json:"ApiVersion,omitempty" name:"ApiVersion"`
// -1:不按项目筛选,获取所有
// >=0: 按项目id筛选
GroupId *int64 `json:"GroupId,omitempty" name:"GroupId"`
// -2: 不按状态筛选,获取所有
// 0: 运行中
// 2: 已停止
Status *int64 `json:"Status,omitempty" name:"Status"`
}
func NewListRuntimeDeployedInstancesMCRequest ¶
func NewListRuntimeDeployedInstancesMCRequest() (request *ListRuntimeDeployedInstancesMCRequest)
func (*ListRuntimeDeployedInstancesMCRequest) FromJsonString ¶
func (r *ListRuntimeDeployedInstancesMCRequest) FromJsonString(s string) error
FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check
func (*ListRuntimeDeployedInstancesMCRequest) ToJsonString ¶
func (r *ListRuntimeDeployedInstancesMCRequest) ToJsonString() string
type ListRuntimeDeployedInstancesMCRequestParams ¶ added in v1.0.426
type ListRuntimeDeployedInstancesMCRequestParams struct {
// 运行时id
RuntimeId *int64 `json:"RuntimeId,omitempty" name:"RuntimeId"`
// 最大请求数量
Limit *int64 `json:"Limit,omitempty" name:"Limit"`
// 请求偏移量
Offset *int64 `json:"Offset,omitempty" name:"Offset"`
// 排序类型:1:创建时间排序, 2:更新时间排序(默认)
SortType *int64 `json:"SortType,omitempty" name:"SortType"`
// 排序方式:asc,desc(默认)
Sort *string `json:"Sort,omitempty" name:"Sort"`
// 运行时地域
Zone *string `json:"Zone,omitempty" name:"Zone"`
// 1:3.0版本新控制台传1;否则传0
ApiVersion *int64 `json:"ApiVersion,omitempty" name:"ApiVersion"`
// -1:不按项目筛选,获取所有
// >=0: 按项目id筛选
GroupId *int64 `json:"GroupId,omitempty" name:"GroupId"`
// -2: 不按状态筛选,获取所有
// 0: 运行中
// 2: 已停止
Status *int64 `json:"Status,omitempty" name:"Status"`
}
Predefined struct for user
type ListRuntimeDeployedInstancesMCResponse ¶
type ListRuntimeDeployedInstancesMCResponse struct {
*tchttp.BaseResponse
Response *ListRuntimeDeployedInstancesMCResponseParams `json:"Response"`
}
func NewListRuntimeDeployedInstancesMCResponse ¶
func NewListRuntimeDeployedInstancesMCResponse() (response *ListRuntimeDeployedInstancesMCResponse)
func (*ListRuntimeDeployedInstancesMCResponse) FromJsonString ¶
func (r *ListRuntimeDeployedInstancesMCResponse) FromJsonString(s string) error
FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check
func (*ListRuntimeDeployedInstancesMCResponse) ToJsonString ¶
func (r *ListRuntimeDeployedInstancesMCResponse) ToJsonString() string
type ListRuntimeDeployedInstancesMCResponseParams ¶ added in v1.0.426
type ListRuntimeDeployedInstancesMCResponseParams struct {
// 运行时所部属的应用实例列表
Instances []*RuntimeDeployedInstanceMC `json:"Instances,omitempty" name:"Instances"`
// 满足条件的记录总数,用于分页器
TotalCount *int64 `json:"TotalCount,omitempty" name:"TotalCount"`
// 唯一请求 ID,每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
RequestId *string `json:"RequestId,omitempty" name:"RequestId"`
}
Predefined struct for user
type ListRuntimesMCRequest ¶
type ListRuntimesMCRequest struct {
*tchttp.BaseRequest
// 环境运行类型:0:运行时类型、1:api类型
RuntimeClass *int64 `json:"RuntimeClass,omitempty" name:"RuntimeClass"`
}
func NewListRuntimesMCRequest ¶
func NewListRuntimesMCRequest() (request *ListRuntimesMCRequest)
func (*ListRuntimesMCRequest) FromJsonString ¶
func (r *ListRuntimesMCRequest) FromJsonString(s string) error
FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check
func (*ListRuntimesMCRequest) ToJsonString ¶
func (r *ListRuntimesMCRequest) ToJsonString() string
type ListRuntimesMCRequestParams ¶ added in v1.0.426
type ListRuntimesMCRequestParams struct {
// 环境运行类型:0:运行时类型、1:api类型
RuntimeClass *int64 `json:"RuntimeClass,omitempty" name:"RuntimeClass"`
}
Predefined struct for user
type ListRuntimesMCResponse ¶
type ListRuntimesMCResponse struct {
*tchttp.BaseResponse
Response *ListRuntimesMCResponseParams `json:"Response"`
}
func NewListRuntimesMCResponse ¶
func NewListRuntimesMCResponse() (response *ListRuntimesMCResponse)
func (*ListRuntimesMCResponse) FromJsonString ¶
func (r *ListRuntimesMCResponse) FromJsonString(s string) error
FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check
func (*ListRuntimesMCResponse) ToJsonString ¶
func (r *ListRuntimesMCResponse) ToJsonString() string
type ListRuntimesMCResponseParams ¶ added in v1.0.426
type ListRuntimesMCResponseParams struct {
// 运行时列表
Runtimes []*RuntimeMC `json:"Runtimes,omitempty" name:"Runtimes"`
// 唯一请求 ID,每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
RequestId *string `json:"RequestId,omitempty" name:"RequestId"`
}
Predefined struct for user
type MetricValueMC ¶
type RuntimeDeployedInstanceMC ¶
type RuntimeDeployedInstanceMC struct {
// 项目id
GroupId *int64 `json:"GroupId,omitempty" name:"GroupId"`
// 项目名称
GroupName *string `json:"GroupName,omitempty" name:"GroupName"`
// 应用id
ProjectId *int64 `json:"ProjectId,omitempty" name:"ProjectId"`
// 应用名称
ProjectName *string `json:"ProjectName,omitempty" name:"ProjectName"`
// 应用实例id
InstanceId *int64 `json:"InstanceId,omitempty" name:"InstanceId"`
// 应用实例版本
InstanceVersion *int64 `json:"InstanceVersion,omitempty" name:"InstanceVersion"`
// 应用实例创建时间
InstanceCreatedAt *int64 `json:"InstanceCreatedAt,omitempty" name:"InstanceCreatedAt"`
// 应用实例部署状态. 0:running, 1:deleting
Status *int64 `json:"Status,omitempty" name:"Status"`
// 应用实例部署创建时间
CreatedAt *int64 `json:"CreatedAt,omitempty" name:"CreatedAt"`
// 应用实例部署更新时间
UpdatedAt *int64 `json:"UpdatedAt,omitempty" name:"UpdatedAt"`
// 应用类型:0:NormalApp普通应用 1:TemplateApp模板应用 2:LightApp轻应用 3:MicroConnTemplate微连接模板 4:MicroConnApp微连接应用
ProjectType *int64 `json:"ProjectType,omitempty" name:"ProjectType"`
// 应用版本:0:旧版 1:3.0新控制台
ProjectVersion *int64 `json:"ProjectVersion,omitempty" name:"ProjectVersion"`
}
type RuntimeExtensionMC ¶ added in v1.0.538
type RuntimeExtensionMC struct {
// 扩展组件类型:0:cdc
Type *int64 `json:"Type,omitempty" name:"Type"`
// 部署规格vcore数
Size *float64 `json:"Size,omitempty" name:"Size"`
// 副本数
Replica *int64 `json:"Replica,omitempty" name:"Replica"`
// 扩展组件名称
Name *string `json:"Name,omitempty" name:"Name"`
// 状态 1:未启用 2:已启用
Status *int64 `json:"Status,omitempty" name:"Status"`
// 创建时间
CreatedAt *int64 `json:"CreatedAt,omitempty" name:"CreatedAt"`
// 修改时间
UpdatedAt *int64 `json:"UpdatedAt,omitempty" name:"UpdatedAt"`
}
type RuntimeMC ¶
type RuntimeMC struct {
// 环境id
RuntimeId *int64 `json:"RuntimeId,omitempty" name:"RuntimeId"`
// 主账号uin
Uin *string `json:"Uin,omitempty" name:"Uin"`
// 环境名称,用户输入,同一uin内唯一
DisplayName *string `json:"DisplayName,omitempty" name:"DisplayName"`
// 环境所在地域,tianjin,beijiing,guangzhou等
Zone *string `json:"Zone,omitempty" name:"Zone"`
// 环境类型:0: sandbox, 1:shared, 2:private 3: trial
Type *int64 `json:"Type,omitempty" name:"Type"`
// 运行时状态:1:running, 2:deleting, 3:creating, 4:scaling, 5:unavailable, 6:deleted, 7:errored
Status *int64 `json:"Status,omitempty" name:"Status"`
// 环境创建时间
CreatedAt *int64 `json:"CreatedAt,omitempty" name:"CreatedAt"`
// 环境更新时间
UpdatedAt *int64 `json:"UpdatedAt,omitempty" name:"UpdatedAt"`
// 环境资源配置,worker总配额,0:0vCore0G, 1:1vCore2G, 2:2vCore4G, 4:4vCore8G, 8:8vCore16G, 12:12vCore24G, 16:16vCore32G, 100:unlimited
WorkerSize *int64 `json:"WorkerSize,omitempty" name:"WorkerSize"`
// 环境资源配置,worker副本数
WorkerReplica *int64 `json:"WorkerReplica,omitempty" name:"WorkerReplica"`
// 正在运行的应用实例数量
RunningInstanceCount *int64 `json:"RunningInstanceCount,omitempty" name:"RunningInstanceCount"`
// 已使用cpu核数
CpuUsed *float64 `json:"CpuUsed,omitempty" name:"CpuUsed"`
// cpu核数上限
CpuLimit *float64 `json:"CpuLimit,omitempty" name:"CpuLimit"`
// 已使用内存 MB
MemoryUsed *float64 `json:"MemoryUsed,omitempty" name:"MemoryUsed"`
// 内存上限 MB
MemoryLimit *float64 `json:"MemoryLimit,omitempty" name:"MemoryLimit"`
// 环境过期时间
// 注意:此字段可能返回 null,表示取不到有效值。
ExpiredAt *int64 `json:"ExpiredAt,omitempty" name:"ExpiredAt"`
// 收费类型:0:缺省,1:自助下单页购买(支持续费/升配等操作),2:代销下单页购买
// 注意:此字段可能返回 null,表示取不到有效值。
ChargeType *int64 `json:"ChargeType,omitempty" name:"ChargeType"`
// 资源限制类型:0:无限制,1:有限制
// 注意:此字段可能返回 null,表示取不到有效值。
ResourceLimitType *int64 `json:"ResourceLimitType,omitempty" name:"ResourceLimitType"`
// 是否开启自动续费
// 注意:此字段可能返回 null,表示取不到有效值。
AutoRenewal *bool `json:"AutoRenewal,omitempty" name:"AutoRenewal"`
// 扩展组件列表
// 注意:此字段可能返回 null,表示取不到有效值。
WorkerExtensions []*RuntimeExtensionMC `json:"WorkerExtensions,omitempty" name:"WorkerExtensions"`
// 环境类型:0: sandbox, 1:shared, 2:private 3: trial
// 注意:此字段可能返回 null,表示取不到有效值。
RuntimeType *int64 `json:"RuntimeType,omitempty" name:"RuntimeType"`
// 环境运行类型:0:运行时类型、1:api类型
// 注意:此字段可能返回 null,表示取不到有效值。
RuntimeClass *int64 `json:"RuntimeClass,omitempty" name:"RuntimeClass"`
// 已使用出带宽 Mbps
// 注意:此字段可能返回 null,表示取不到有效值。
BandwidthOutUsed *float64 `json:"BandwidthOutUsed,omitempty" name:"BandwidthOutUsed"`
// 出带宽上限 Mbps
// 注意:此字段可能返回 null,表示取不到有效值。
BandwidthOutLimit *float64 `json:"BandwidthOutLimit,omitempty" name:"BandwidthOutLimit"`
}