Documentation
¶
Index ¶
- Constants
- type Client
- func (c *Client) DescribeImageStat(request *DescribeImageStatRequest) (response *DescribeImageStatResponse, err error)
- func (c *Client) DescribeImageStatWithContext(ctx context.Context, request *DescribeImageStatRequest) (response *DescribeImageStatResponse, err error)
- func (c *Client) DescribeImsList(request *DescribeImsListRequest) (response *DescribeImsListResponse, err error)
- func (c *Client) DescribeImsListWithContext(ctx context.Context, request *DescribeImsListRequest) (response *DescribeImsListResponse, err error)
- func (c *Client) ImageModeration(request *ImageModerationRequest) (response *ImageModerationResponse, err error)
- func (c *Client) ImageModerationWithContext(ctx context.Context, request *ImageModerationRequest) (response *ImageModerationResponse, err error)
- type DescribeImageStatRequest
- type DescribeImageStatResponse
- type DescribeImsListRequest
- type DescribeImsListResponse
- type Device
- type EvilCount
- type Filter
- type Filters
- type ImageModerationRequest
- type ImageModerationResponse
- type ImsDetail
- type LabelDetailItem
- type LabelResult
- type LibDetail
- type LibResult
- type Location
- type ObjectDetail
- type ObjectResult
- type OcrResult
- type OcrTextDetail
- type Overview
- type TrendCount
- type User
Constants ¶
const ( // DryRun 操作,代表请求将会是成功的,只是多传了 DryRun 参数。 DRYRUNOPERATION = "DryRunOperation" // 操作失败。 FAILEDOPERATION = "FailedOperation" // 内部错误。 INTERNALERROR = "InternalError" // 内部错误。 INTERNALERROR_INTERNALERROR = "InternalError.InternalError" // 参数错误。 INVALIDPARAMETER = "InvalidParameter" // 图片分辨率过低。 INVALIDPARAMETER_IMAGESIZETOOSMALL = "InvalidParameter.ImageSizeTooSmall" // 图片内容错误。 INVALIDPARAMETER_INVALIDIMAGECONTENT = "InvalidParameter.InvalidImageContent" // 参数取值错误。 INVALIDPARAMETERVALUE = "InvalidParameterValue" // 图片内容参数为空。 INVALIDPARAMETERVALUE_EMPTYIMAGECONTENT = "InvalidParameterValue.EmptyImageContent" // 图片分辨率太低。 INVALIDPARAMETERVALUE_IMAGESIZETOOSMALL = "InvalidParameterValue.ImageSizeTooSmall" // FileContent和FileUrl为空。 INVALIDPARAMETERVALUE_INVALIDCONTENT = "InvalidParameterValue.InvalidContent" // DataId格式错误。 INVALIDPARAMETERVALUE_INVALIDDATAID = "InvalidParameterValue.InvalidDataId" // 图片文件内容大小异常。 INVALIDPARAMETERVALUE_INVALIDFILECONTENTSIZE = "InvalidParameterValue.InvalidFileContentSize" // 图片内容错误。 INVALIDPARAMETERVALUE_INVALIDIMAGECONTENT = "InvalidParameterValue.InvalidImageContent" // 参数值错误。 INVALIDPARAMETERVALUE_INVALIDPARAMETER = "InvalidParameterValue.InvalidParameter" // 超过配额限制。 LIMITEXCEEDED = "LimitExceeded" // 缺少参数错误。 MISSINGPARAMETER = "MissingParameter" // 操作被拒绝。 OPERATIONDENIED = "OperationDenied" // 请求的次数超过了频率限制。 REQUESTLIMITEXCEEDED = "RequestLimitExceeded" // 资源被占用。 RESOURCEINUSE = "ResourceInUse" // 资源不足。 RESOURCEINSUFFICIENT = "ResourceInsufficient" // 资源不存在。 RESOURCENOTFOUND = "ResourceNotFound" // 资源不可用。 RESOURCEUNAVAILABLE = "ResourceUnavailable" // 图片文件下载失败。 RESOURCEUNAVAILABLE_IMAGEDOWNLOADERROR = "ResourceUnavailable.ImageDownloadError" // 图片资源错误。 RESOURCEUNAVAILABLE_INVALIDIMAGECONTENT = "ResourceUnavailable.InvalidImageContent" // 资源售罄。 RESOURCESSOLDOUT = "ResourcesSoldOut" // 未授权操作。 UNAUTHORIZEDOPERATION = "UnauthorizedOperation" // 未知参数错误。 UNKNOWNPARAMETER = "UnknownParameter" // 操作不支持。 UNSUPPORTEDOPERATION = "UnsupportedOperation" )
const APIVersion = "2020-07-13"
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
func NewClient ¶
func NewClient(credential common.CredentialIface, region string, clientProfile *profile.ClientProfile) (client *Client, err error)
func NewClientWithSecretId ¶
Deprecated
func (*Client) DescribeImageStat ¶
func (c *Client) DescribeImageStat(request *DescribeImageStatRequest) (response *DescribeImageStatResponse, err error)
DescribeImageStat 控制台识别统计
可能返回的错误码:
INTERNALERROR = "InternalError" INTERNALERROR_INTERNALERROR = "InternalError.InternalError" INVALIDPARAMETER = "InvalidParameter" INVALIDPARAMETERVALUE = "InvalidParameterValue" MISSINGPARAMETER = "MissingParameter" OPERATIONDENIED = "OperationDenied" RESOURCEINSUFFICIENT = "ResourceInsufficient" RESOURCENOTFOUND = "ResourceNotFound"
func (*Client) DescribeImageStatWithContext ¶ added in v1.0.324
func (c *Client) DescribeImageStatWithContext(ctx context.Context, request *DescribeImageStatRequest) (response *DescribeImageStatResponse, err error)
DescribeImageStat 控制台识别统计
可能返回的错误码:
INTERNALERROR = "InternalError" INTERNALERROR_INTERNALERROR = "InternalError.InternalError" INVALIDPARAMETER = "InvalidParameter" INVALIDPARAMETERVALUE = "InvalidParameterValue" MISSINGPARAMETER = "MissingParameter" OPERATIONDENIED = "OperationDenied" RESOURCEINSUFFICIENT = "ResourceInsufficient" RESOURCENOTFOUND = "ResourceNotFound"
func (*Client) DescribeImsList ¶
func (c *Client) DescribeImsList(request *DescribeImsListRequest) (response *DescribeImsListResponse, err error)
DescribeImsList 图片机器审核明细
可能返回的错误码:
FAILEDOPERATION = "FailedOperation" INTERNALERROR = "InternalError" INTERNALERROR_INTERNALERROR = "InternalError.InternalError" INVALIDPARAMETER = "InvalidParameter" INVALIDPARAMETERVALUE = "InvalidParameterValue" MISSINGPARAMETER = "MissingParameter" RESOURCENOTFOUND = "ResourceNotFound"
func (*Client) DescribeImsListWithContext ¶ added in v1.0.324
func (c *Client) DescribeImsListWithContext(ctx context.Context, request *DescribeImsListRequest) (response *DescribeImsListResponse, err error)
DescribeImsList 图片机器审核明细
可能返回的错误码:
FAILEDOPERATION = "FailedOperation" INTERNALERROR = "InternalError" INTERNALERROR_INTERNALERROR = "InternalError.InternalError" INVALIDPARAMETER = "InvalidParameter" INVALIDPARAMETERVALUE = "InvalidParameterValue" MISSINGPARAMETER = "MissingParameter" RESOURCENOTFOUND = "ResourceNotFound"
func (*Client) ImageModeration ¶
func (c *Client) ImageModeration(request *ImageModerationRequest) (response *ImageModerationResponse, err error)
ImageModeration 图片内容检测服务(Image Moderation, IM)能自动扫描图片,识别可能令人反感、不安全或不适宜的内容,同时支持用户配置图片黑名单,打击自定义识别类型的图片。
<div class="rno-api-explorer" style="margin-bottom:20px">
<div class="rno-api-explorer-inner">
<div class="rno-api-explorer-hd">
<div class="rno-api-explorer-title">
关于版本迭代的描述
</div>
</div>
<div class="rno-api-explorer-body">
<div class="rno-api-explorer-cont">
<p>当前页面版本为图片内容安全2020版本,2020.11.3日前接入的图片内容安全接口为2019版本,在此时间前接入的用户可直接访问以下链接进行维护操作:<a href="https://cloud.tencent.com/document/product/1125/38206" target="_blank">图片内容安全-2019版本</a></p>
<p>2020版本相对2019版本进行了升级,支持更灵活的多场景业务策略配置以及更丰富的识别回调信息,满足不同业务的识别需求,建议按照2020版本接入指引进行接口升级;同时,2019版本也会持续维护直至用户不再使用为止。</p>
</div>
</div>
</div>
</div>
可能返回的错误码:
DRYRUNOPERATION = "DryRunOperation" FAILEDOPERATION = "FailedOperation" INTERNALERROR = "InternalError" INTERNALERROR_INTERNALERROR = "InternalError.InternalError" INVALIDPARAMETER = "InvalidParameter" INVALIDPARAMETER_IMAGESIZETOOSMALL = "InvalidParameter.ImageSizeTooSmall" INVALIDPARAMETER_INVALIDIMAGECONTENT = "InvalidParameter.InvalidImageContent" INVALIDPARAMETERVALUE = "InvalidParameterValue" INVALIDPARAMETERVALUE_EMPTYIMAGECONTENT = "InvalidParameterValue.EmptyImageContent" INVALIDPARAMETERVALUE_IMAGESIZETOOSMALL = "InvalidParameterValue.ImageSizeTooSmall" INVALIDPARAMETERVALUE_INVALIDCONTENT = "InvalidParameterValue.InvalidContent" INVALIDPARAMETERVALUE_INVALIDDATAID = "InvalidParameterValue.InvalidDataId" INVALIDPARAMETERVALUE_INVALIDFILECONTENTSIZE = "InvalidParameterValue.InvalidFileContentSize" INVALIDPARAMETERVALUE_INVALIDIMAGECONTENT = "InvalidParameterValue.InvalidImageContent" INVALIDPARAMETERVALUE_INVALIDPARAMETER = "InvalidParameterValue.InvalidParameter" LIMITEXCEEDED = "LimitExceeded" MISSINGPARAMETER = "MissingParameter" OPERATIONDENIED = "OperationDenied" REQUESTLIMITEXCEEDED = "RequestLimitExceeded" RESOURCEINUSE = "ResourceInUse" RESOURCEINSUFFICIENT = "ResourceInsufficient" RESOURCENOTFOUND = "ResourceNotFound" RESOURCEUNAVAILABLE = "ResourceUnavailable" RESOURCEUNAVAILABLE_IMAGEDOWNLOADERROR = "ResourceUnavailable.ImageDownloadError" RESOURCEUNAVAILABLE_INVALIDIMAGECONTENT = "ResourceUnavailable.InvalidImageContent" RESOURCESSOLDOUT = "ResourcesSoldOut" UNAUTHORIZEDOPERATION = "UnauthorizedOperation" UNKNOWNPARAMETER = "UnknownParameter" UNSUPPORTEDOPERATION = "UnsupportedOperation"
func (*Client) ImageModerationWithContext ¶ added in v1.0.324
func (c *Client) ImageModerationWithContext(ctx context.Context, request *ImageModerationRequest) (response *ImageModerationResponse, err error)
ImageModeration 图片内容检测服务(Image Moderation, IM)能自动扫描图片,识别可能令人反感、不安全或不适宜的内容,同时支持用户配置图片黑名单,打击自定义识别类型的图片。
<div class="rno-api-explorer" style="margin-bottom:20px">
<div class="rno-api-explorer-inner">
<div class="rno-api-explorer-hd">
<div class="rno-api-explorer-title">
关于版本迭代的描述
</div>
</div>
<div class="rno-api-explorer-body">
<div class="rno-api-explorer-cont">
<p>当前页面版本为图片内容安全2020版本,2020.11.3日前接入的图片内容安全接口为2019版本,在此时间前接入的用户可直接访问以下链接进行维护操作:<a href="https://cloud.tencent.com/document/product/1125/38206" target="_blank">图片内容安全-2019版本</a></p>
<p>2020版本相对2019版本进行了升级,支持更灵活的多场景业务策略配置以及更丰富的识别回调信息,满足不同业务的识别需求,建议按照2020版本接入指引进行接口升级;同时,2019版本也会持续维护直至用户不再使用为止。</p>
</div>
</div>
</div>
</div>
可能返回的错误码:
DRYRUNOPERATION = "DryRunOperation" FAILEDOPERATION = "FailedOperation" INTERNALERROR = "InternalError" INTERNALERROR_INTERNALERROR = "InternalError.InternalError" INVALIDPARAMETER = "InvalidParameter" INVALIDPARAMETER_IMAGESIZETOOSMALL = "InvalidParameter.ImageSizeTooSmall" INVALIDPARAMETER_INVALIDIMAGECONTENT = "InvalidParameter.InvalidImageContent" INVALIDPARAMETERVALUE = "InvalidParameterValue" INVALIDPARAMETERVALUE_EMPTYIMAGECONTENT = "InvalidParameterValue.EmptyImageContent" INVALIDPARAMETERVALUE_IMAGESIZETOOSMALL = "InvalidParameterValue.ImageSizeTooSmall" INVALIDPARAMETERVALUE_INVALIDCONTENT = "InvalidParameterValue.InvalidContent" INVALIDPARAMETERVALUE_INVALIDDATAID = "InvalidParameterValue.InvalidDataId" INVALIDPARAMETERVALUE_INVALIDFILECONTENTSIZE = "InvalidParameterValue.InvalidFileContentSize" INVALIDPARAMETERVALUE_INVALIDIMAGECONTENT = "InvalidParameterValue.InvalidImageContent" INVALIDPARAMETERVALUE_INVALIDPARAMETER = "InvalidParameterValue.InvalidParameter" LIMITEXCEEDED = "LimitExceeded" MISSINGPARAMETER = "MissingParameter" OPERATIONDENIED = "OperationDenied" REQUESTLIMITEXCEEDED = "RequestLimitExceeded" RESOURCEINUSE = "ResourceInUse" RESOURCEINSUFFICIENT = "ResourceInsufficient" RESOURCENOTFOUND = "ResourceNotFound" RESOURCEUNAVAILABLE = "ResourceUnavailable" RESOURCEUNAVAILABLE_IMAGEDOWNLOADERROR = "ResourceUnavailable.ImageDownloadError" RESOURCEUNAVAILABLE_INVALIDIMAGECONTENT = "ResourceUnavailable.InvalidImageContent" RESOURCESSOLDOUT = "ResourcesSoldOut" UNAUTHORIZEDOPERATION = "UnauthorizedOperation" UNKNOWNPARAMETER = "UnknownParameter" UNSUPPORTEDOPERATION = "UnsupportedOperation"
type DescribeImageStatRequest ¶
type DescribeImageStatRequest struct {
*tchttp.BaseRequest
// 审核类型 1: 机器审核; 2: 人工审核
AuditType *int64 `json:"AuditType,omitempty" name:"AuditType"`
// 查询条件
Filters []*Filters `json:"Filters,omitempty" name:"Filters"`
}
func NewDescribeImageStatRequest ¶
func NewDescribeImageStatRequest() (request *DescribeImageStatRequest)
func (*DescribeImageStatRequest) FromJsonString ¶
func (r *DescribeImageStatRequest) FromJsonString(s string) error
FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check
func (*DescribeImageStatRequest) ToJsonString ¶
func (r *DescribeImageStatRequest) ToJsonString() string
type DescribeImageStatResponse ¶
type DescribeImageStatResponse struct {
*tchttp.BaseResponse
Response *struct {
// 识别结果统计
Overview *Overview `json:"Overview,omitempty" name:"Overview"`
// 识别量统计
TrendCount []*TrendCount `json:"TrendCount,omitempty" name:"TrendCount"`
// 违规数据分布
// 注意:此字段可能返回 null,表示取不到有效值。
EvilCount []*EvilCount `json:"EvilCount,omitempty" name:"EvilCount"`
// 唯一请求 ID,每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
RequestId *string `json:"RequestId,omitempty" name:"RequestId"`
} `json:"Response"`
}
func NewDescribeImageStatResponse ¶
func NewDescribeImageStatResponse() (response *DescribeImageStatResponse)
func (*DescribeImageStatResponse) FromJsonString ¶
func (r *DescribeImageStatResponse) FromJsonString(s string) error
FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check
func (*DescribeImageStatResponse) ToJsonString ¶
func (r *DescribeImageStatResponse) ToJsonString() string
type DescribeImsListRequest ¶
type DescribeImsListRequest struct {
*tchttp.BaseRequest
// 分页 页索引
PageIndex *int64 `json:"PageIndex,omitempty" name:"PageIndex"`
// 分页条数
PageSize *int64 `json:"PageSize,omitempty" name:"PageSize"`
// 过滤条件
Filters []*Filter `json:"Filters,omitempty" name:"Filters"`
}
func NewDescribeImsListRequest ¶
func NewDescribeImsListRequest() (request *DescribeImsListRequest)
func (*DescribeImsListRequest) FromJsonString ¶
func (r *DescribeImsListRequest) FromJsonString(s string) error
FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check
func (*DescribeImsListRequest) ToJsonString ¶
func (r *DescribeImsListRequest) ToJsonString() string
type DescribeImsListResponse ¶
type DescribeImsListResponse struct {
*tchttp.BaseResponse
Response *struct {
// 返回列表数据----非必选,该参数暂未对外开放
// 注意:此字段可能返回 null,表示取不到有效值。
ImsDetailSet []*ImsDetail `json:"ImsDetailSet,omitempty" name:"ImsDetailSet"`
// 总条数
TotalCount *int64 `json:"TotalCount,omitempty" name:"TotalCount"`
// 唯一请求 ID,每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
RequestId *string `json:"RequestId,omitempty" name:"RequestId"`
} `json:"Response"`
}
func NewDescribeImsListResponse ¶
func NewDescribeImsListResponse() (response *DescribeImsListResponse)
func (*DescribeImsListResponse) FromJsonString ¶
func (r *DescribeImsListResponse) FromJsonString(s string) error
FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check
func (*DescribeImsListResponse) ToJsonString ¶
func (r *DescribeImsListResponse) ToJsonString() string
type Device ¶
type Device struct {
// 发表消息设备IP
Ip *string `json:"Ip,omitempty" name:"Ip"`
// Mac地址
Mac *string `json:"Mac,omitempty" name:"Mac"`
// 设备指纹Token
TokenId *string `json:"TokenId,omitempty" name:"TokenId"`
// 设备指纹ID
DeviceId *string `json:"DeviceId,omitempty" name:"DeviceId"`
// 设备序列号
IMEI *string `json:"IMEI,omitempty" name:"IMEI"`
// IOS设备,Identifier For Advertising(广告标识符)
IDFA *string `json:"IDFA,omitempty" name:"IDFA"`
// IOS设备,IDFV - Identifier For Vendor(应用开发商标识符)
IDFV *string `json:"IDFV,omitempty" name:"IDFV"`
// IP地址类型 0 代表ipv4 1 代表ipv6
IpType *uint64 `json:"IpType,omitempty" name:"IpType"`
}
type ImageModerationRequest ¶
type ImageModerationRequest struct {
*tchttp.BaseRequest
// 该字段用于标识业务场景。您可以在内容安全控制台创建对应的ID,配置不同的内容审核策略,通过接口调用,默认不填为0,后端使用默认策略。 -- 该字段暂未开放。
BizType *string `json:"BizType,omitempty" name:"BizType"`
// 数据ID,可以由英文字母、数字、下划线、-、@#组成,不超过64个字符
DataId *string `json:"DataId,omitempty" name:"DataId"`
// 数据Base64编码,图片检测接口为图片文件内容,大小不能超过5M
FileContent *string `json:"FileContent,omitempty" name:"FileContent"`
// 图片资源访问链接,__与FileContent参数必须二选一输入__
FileUrl *string `json:"FileUrl,omitempty" name:"FileUrl"`
// 截帧频率,GIF图/长图检测专用,默认值为0,表示只会检测GIF图/长图的第一帧
Interval *int64 `json:"Interval,omitempty" name:"Interval"`
// GIF图/长图检测专用,代表均匀最大截帧数量,默认值为1(即只取GIF第一张,或长图不做切分处理(可能会造成处理超时))。
MaxFrames *int64 `json:"MaxFrames,omitempty" name:"MaxFrames"`
// 账号相关信息字段,填入后可识别违规风险账号。
User *User `json:"User,omitempty" name:"User"`
// 设备相关信息字段,填入后可识别违规风险设备。
Device *Device `json:"Device,omitempty" name:"Device"`
}
func NewImageModerationRequest ¶
func NewImageModerationRequest() (request *ImageModerationRequest)
func (*ImageModerationRequest) FromJsonString ¶
func (r *ImageModerationRequest) FromJsonString(s string) error
FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check
func (*ImageModerationRequest) ToJsonString ¶
func (r *ImageModerationRequest) ToJsonString() string
type ImageModerationResponse ¶
type ImageModerationResponse struct {
*tchttp.BaseResponse
Response *struct {
// 数据是否属于恶意类型。
// 0:正常,1:可疑;
HitFlag *int64 `json:"HitFlag,omitempty" name:"HitFlag"`
// 建议您拿到判断结果后的执行操作。
// 建议值,Block:建议屏蔽,Review:建议复审,Pass:建议通过
Suggestion *string `json:"Suggestion,omitempty" name:"Suggestion"`
// 恶意标签,Normal:正常,Porn:色情,Abuse:谩骂,Ad:广告,Custom:自定义图片。
// 以及令人反感、不安全或不适宜的内容类型。
Label *string `json:"Label,omitempty" name:"Label"`
// 子标签名称,如色情--性行为;当未命中子标签时,返回空字符串;
SubLabel *string `json:"SubLabel,omitempty" name:"SubLabel"`
// 机器判断当前分类的置信度,取值范围:0.00~100.00。分数越高,表示越有可能属于当前分类。
// (如:色情 99.99,则该样本属于色情的置信度非常高。)
Score *int64 `json:"Score,omitempty" name:"Score"`
// 智能模型的识别结果,包括涉黄、广告等令人反感、不安全或不适宜的内容类型识别结果。
// 注意:此字段可能返回 null,表示取不到有效值。
LabelResults []*LabelResult `json:"LabelResults,omitempty" name:"LabelResults"`
// 物体检测模型的审核结果,包括实体、广告台标/二维码等物体坐标信息与内容审核信息。
// 注意:此字段可能返回 null,表示取不到有效值。
ObjectResults []*ObjectResult `json:"ObjectResults,omitempty" name:"ObjectResults"`
// OCR识别后的文本识别结果,包括文本所处图片的OCR坐标信息以及图片文本的识别结果。
// 注意:此字段可能返回 null,表示取不到有效值。
OcrResults []*OcrResult `json:"OcrResults,omitempty" name:"OcrResults"`
// 基于图片风险库识别的结果。
// 风险库包括不安全黑库与正常白库的结果。
// 注意:此字段可能返回 null,表示取不到有效值。
LibResults []*LibResult `json:"LibResults,omitempty" name:"LibResults"`
// 请求参数中的DataId。
DataId *string `json:"DataId,omitempty" name:"DataId"`
// 您在入参时所填入的Biztype参数。 -- 该字段暂未开放。
BizType *string `json:"BizType,omitempty" name:"BizType"`
// 扩展字段,用于特定信息返回,不同客户/Biztype下返回信息不同。
// 注意:此字段可能返回 null,表示取不到有效值。
// 注意:此字段可能返回 null,表示取不到有效值。
Extra *string `json:"Extra,omitempty" name:"Extra"`
// 唯一请求 ID,每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
RequestId *string `json:"RequestId,omitempty" name:"RequestId"`
} `json:"Response"`
}
func NewImageModerationResponse ¶
func NewImageModerationResponse() (response *ImageModerationResponse)
func (*ImageModerationResponse) FromJsonString ¶
func (r *ImageModerationResponse) FromJsonString(s string) error
FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check
func (*ImageModerationResponse) ToJsonString ¶
func (r *ImageModerationResponse) ToJsonString() string
type ImsDetail ¶
type ImsDetail struct {
// 文本内容
Content *string `json:"Content,omitempty" name:"Content"`
// 数据方式, 0:我审,1:人审
DataSource *int64 `json:"DataSource,omitempty" name:"DataSource"`
// 最后更新时间
UpdateTime *string `json:"UpdateTime,omitempty" name:"UpdateTime"`
// ----非必选,该参数暂未对外开放
EvilType *int64 `json:"EvilType,omitempty" name:"EvilType"`
// 机器审核时间
ModerationTime *string `json:"ModerationTime,omitempty" name:"ModerationTime"`
// 最后更新人
UpdateUser *string `json:"UpdateUser,omitempty" name:"UpdateUser"`
// 内容RequestId
ContentId *string `json:"ContentId,omitempty" name:"ContentId"`
// 自主审核结果
OperEvilType *int64 `json:"OperEvilType,omitempty" name:"OperEvilType"`
}
type LabelDetailItem ¶
type LabelResult ¶
type LabelResult struct {
// 场景识别结果
Scene *string `json:"Scene,omitempty" name:"Scene"`
// 建议您拿到判断结果后的执行操作。
// 建议值,Block:建议屏蔽,Review:建议复审,Pass:建议通过
Suggestion *string `json:"Suggestion,omitempty" name:"Suggestion"`
// 恶意标签,Normal:正常,Porn:色情,Abuse:谩骂,Ad:广告,Custom:自定义图片。
// 以及令人反感、不安全或不适宜的内容类型。
Label *string `json:"Label,omitempty" name:"Label"`
// 子标签检测结果
// 注意:此字段可能返回 null,表示取不到有效值。
SubLabel *string `json:"SubLabel,omitempty" name:"SubLabel"`
// 该标签模型命中的分值
Score *uint64 `json:"Score,omitempty" name:"Score"`
// 分类模型命中子标签结果
// 注意:此字段可能返回 null,表示取不到有效值。
Details []*LabelDetailItem `json:"Details,omitempty" name:"Details"`
}
type LibDetail ¶
type LibDetail struct {
// 序号
Id *int64 `json:"Id,omitempty" name:"Id"`
// 仅当Label为Custom自定义关键词时有效,表示自定义库id
LibId *string `json:"LibId,omitempty" name:"LibId"`
// 仅当Label为Custom自定义关键词时有效,表示自定义库名称
// 注意:此字段可能返回 null,表示取不到有效值。
LibName *string `json:"LibName,omitempty" name:"LibName"`
// 图片ID
ImageId *string `json:"ImageId,omitempty" name:"ImageId"`
// 恶意标签,Normal:正常,Porn:色情,Abuse:谩骂,Ad:广告,Custom:自定义词库。
// 以及其他令人反感、不安全或不适宜的内容类型。
Label *string `json:"Label,omitempty" name:"Label"`
// 自定义标签
// 注意:此字段可能返回 null,表示取不到有效值。
Tag *string `json:"Tag,omitempty" name:"Tag"`
// 命中的模型分值
Score *int64 `json:"Score,omitempty" name:"Score"`
}
type LibResult ¶
type LibResult struct {
// 场景识别结果
Scene *string `json:"Scene,omitempty" name:"Scene"`
// 建议您拿到判断结果后的执行操作。
// 建议值,Block:建议屏蔽,Review:建议复审,Pass:建议通过
Suggestion *string `json:"Suggestion,omitempty" name:"Suggestion"`
// 恶意标签,Normal:正常,Porn:色情,Abuse:谩骂,Ad:广告,Custom:自定义词库。
// 以及令人反感、不安全或不适宜的内容类型。
Label *string `json:"Label,omitempty" name:"Label"`
// 子标签检测结果
// 注意:此字段可能返回 null,表示取不到有效值。
SubLabel *string `json:"SubLabel,omitempty" name:"SubLabel"`
// 该标签模型命中的分值
Score *int64 `json:"Score,omitempty" name:"Score"`
// 黑白库结果明细
// 注意:此字段可能返回 null,表示取不到有效值。
Details []*LibDetail `json:"Details,omitempty" name:"Details"`
}
type Location ¶
type Location struct {
// 左上角横坐标
X *float64 `json:"X,omitempty" name:"X"`
// 左上角纵坐标
Y *float64 `json:"Y,omitempty" name:"Y"`
// 宽度
Width *float64 `json:"Width,omitempty" name:"Width"`
// 高度
Height *float64 `json:"Height,omitempty" name:"Height"`
// 检测框的旋转角度
Rotate *float64 `json:"Rotate,omitempty" name:"Rotate"`
}
type ObjectDetail ¶
type ObjectDetail struct {
// 序号
Id *uint64 `json:"Id,omitempty" name:"Id"`
// 标签名称
Name *string `json:"Name,omitempty" name:"Name"`
// 标签值,
// 当标签为二维码时,表示URL地址,如Name为QrCode时,Value为"http//abc.com/aaa"
Value *string `json:"Value,omitempty" name:"Value"`
// 分数
Score *uint64 `json:"Score,omitempty" name:"Score"`
// 检测框坐标
Location *Location `json:"Location,omitempty" name:"Location"`
}
type ObjectResult ¶
type ObjectResult struct {
// 场景识别结果
Scene *string `json:"Scene,omitempty" name:"Scene"`
// 建议您拿到判断结果后的执行操作。
// 建议值,Block:建议屏蔽,Review:建议复审,Pass:建议通过
Suggestion *string `json:"Suggestion,omitempty" name:"Suggestion"`
// 恶意标签,Normal:正常,Porn:色情,Abuse:谩骂,Ad:广告,Custom:自定义图片。
// 以及令人反感、不安全或不适宜的内容类型。
Label *string `json:"Label,omitempty" name:"Label"`
// 子标签检测结果
// 注意:此字段可能返回 null,表示取不到有效值。
SubLabel *string `json:"SubLabel,omitempty" name:"SubLabel"`
// 该标签模型命中的分值
Score *uint64 `json:"Score,omitempty" name:"Score"`
// 实体名称
// 注意:此字段可能返回 null,表示取不到有效值。
Names []*string `json:"Names,omitempty" name:"Names"`
// 实体检测结果明细
// 注意:此字段可能返回 null,表示取不到有效值。
Details []*ObjectDetail `json:"Details,omitempty" name:"Details"`
}
type OcrResult ¶
type OcrResult struct {
// 场景识别结果
Scene *string `json:"Scene,omitempty" name:"Scene"`
// 建议您拿到判断结果后的执行操作。
// 建议值,Block:建议屏蔽,Review:建议复审,Pass:建议通过
Suggestion *string `json:"Suggestion,omitempty" name:"Suggestion"`
// 恶意标签,Normal:正常,Porn:色情,Abuse:谩骂,Ad:广告,Custom:自定义词库。
// 以及令人反感、不安全或不适宜的内容类型。
Label *string `json:"Label,omitempty" name:"Label"`
// 子标签检测结果
SubLabel *string `json:"SubLabel,omitempty" name:"SubLabel"`
// 该标签模型命中的分值
Score *uint64 `json:"Score,omitempty" name:"Score"`
// ocr结果详情
Details []*OcrTextDetail `json:"Details,omitempty" name:"Details"`
// ocr识别出的文本结果
Text *string `json:"Text,omitempty" name:"Text"`
}
type OcrTextDetail ¶
type OcrTextDetail struct {
// OCR文本内容
Text *string `json:"Text,omitempty" name:"Text"`
// 恶意标签,Normal:正常,Porn:色情,Abuse:谩骂,Ad:广告,Custom:自定义词库。
// 以及令人反感、不安全或不适宜的内容类型。
Label *string `json:"Label,omitempty" name:"Label"`
// 仅当Label为Custom自定义关键词时有效,表示自定义库id
LibId *string `json:"LibId,omitempty" name:"LibId"`
// 仅当Label为Custom自定义关键词时有效,表示自定义库名称
LibName *string `json:"LibName,omitempty" name:"LibName"`
// 该标签下命中的关键词
Keywords []*string `json:"Keywords,omitempty" name:"Keywords"`
// 该标签模型命中的分值
Score *uint64 `json:"Score,omitempty" name:"Score"`
// OCR位置
Location *Location `json:"Location,omitempty" name:"Location"`
// OCR文本识别置信度
Rate *uint64 `json:"Rate,omitempty" name:"Rate"`
}
type Overview ¶
type Overview struct {
// 总调用量
TotalCount *int64 `json:"TotalCount,omitempty" name:"TotalCount"`
// 总调用时长
TotalHour *int64 `json:"TotalHour,omitempty" name:"TotalHour"`
// 通过量
PassCount *int64 `json:"PassCount,omitempty" name:"PassCount"`
// 通过时长
PassHour *int64 `json:"PassHour,omitempty" name:"PassHour"`
// 违规量
EvilCount *int64 `json:"EvilCount,omitempty" name:"EvilCount"`
// 违规时长
EvilHour *int64 `json:"EvilHour,omitempty" name:"EvilHour"`
// 疑似违规量
SuspectCount *int64 `json:"SuspectCount,omitempty" name:"SuspectCount"`
// 疑似违规时长
SuspectHour *int64 `json:"SuspectHour,omitempty" name:"SuspectHour"`
}
type TrendCount ¶
type TrendCount struct {
// 总调用量
// 注意:此字段可能返回 null,表示取不到有效值。
TotalCount *int64 `json:"TotalCount,omitempty" name:"TotalCount"`
// 总调用时长
// 注意:此字段可能返回 null,表示取不到有效值。
TotalHour *int64 `json:"TotalHour,omitempty" name:"TotalHour"`
// 通过量
// 注意:此字段可能返回 null,表示取不到有效值。
PassCount *int64 `json:"PassCount,omitempty" name:"PassCount"`
// 通过时长
// 注意:此字段可能返回 null,表示取不到有效值。
PassHour *int64 `json:"PassHour,omitempty" name:"PassHour"`
// 违规量
// 注意:此字段可能返回 null,表示取不到有效值。
EvilCount *int64 `json:"EvilCount,omitempty" name:"EvilCount"`
// 违规时长
// 注意:此字段可能返回 null,表示取不到有效值。
EvilHour *int64 `json:"EvilHour,omitempty" name:"EvilHour"`
// 疑似违规量
// 注意:此字段可能返回 null,表示取不到有效值。
SuspectCount *int64 `json:"SuspectCount,omitempty" name:"SuspectCount"`
// 疑似违规时长
// 注意:此字段可能返回 null,表示取不到有效值。
SuspectHour *int64 `json:"SuspectHour,omitempty" name:"SuspectHour"`
// 日期
// 注意:此字段可能返回 null,表示取不到有效值。
Date *string `json:"Date,omitempty" name:"Date"`
}
type User ¶
type User struct {
// 业务用户ID 如填写,会根据账号历史恶意情况,判定消息有害结果,特别是有利于可疑恶意情况下的辅助判断。账号可以填写微信uin、QQ号、微信openid、QQopenid、字符串等。该字段和账号类别确定唯一账号。
UserId *string `json:"UserId,omitempty" name:"UserId"`
// 业务用户ID类型 "1-微信uin 2-QQ号 3-微信群uin 4-qq群号 5-微信openid 6-QQopenid 7-其它string"
AccountType *string `json:"AccountType,omitempty" name:"AccountType"`
// 用户昵称
Nickname *string `json:"Nickname,omitempty" name:"Nickname"`
// 性别 默认0 未知 1 男性 2 女性
Gender *uint64 `json:"Gender,omitempty" name:"Gender"`
// 年龄 默认0 未知
Age *uint64 `json:"Age,omitempty" name:"Age"`
// 用户等级,默认0 未知 1 低 2 中 3 高
Level *uint64 `json:"Level,omitempty" name:"Level"`
// 手机号
Phone *string `json:"Phone,omitempty" name:"Phone"`
// 用户简介,长度不超过5000字
Desc *string `json:"Desc,omitempty" name:"Desc"`
// 用户头像图片链接
HeadUrl *string `json:"HeadUrl,omitempty" name:"HeadUrl"`
}