v20210119

package
v1.0.521 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 25, 2022 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

const (

	// CAM签名/鉴权错误。
	AUTHFAILURE = "AuthFailure"

	// 内部错误。
	INTERNALERROR = "InternalError"

	// 请求控制器发生错误。
	INTERNALERROR_CONTROLREQUESTERROR = "InternalError.ControlRequestError"

	// 文件读写异常。
	INTERNALERROR_FILEIOERROR = "InternalError.FileIOError"

	// 智研流量数据请求错误。
	INTERNALERROR_NETWORKINFOREQUESTERROR = "InternalError.NetworkInfoRequestError"

	// 参数错误。
	INVALIDPARAMETER = "InvalidParameter"

	// 参数取值错误。
	INVALIDPARAMETERVALUE = "InvalidParameterValue"

	// 无法获取到可加速的运营商信息
	INVALIDPARAMETERVALUE_VENDORNOTFOUND = "InvalidParameterValue.VendorNotFound"

	// 缺少参数错误。
	MISSINGPARAMETER = "MissingParameter"

	// 操作被拒绝。
	OPERATIONDENIED = "OperationDenied"

	// 不建议加速。
	OPERATIONDENIED_ACCELERATIONNOTSUGGEST = "OperationDenied.AccelerationNotSuggest"

	// 中国电信加速token过期。
	OPERATIONDENIED_CTCCTOKENEXPIRED = "OperationDenied.CTCCTokenExpired"

	// 相同加速间隔时间过短。
	OPERATIONDENIED_CREATEQOSEXCEEDLIMIT = "OperationDenied.CreateQosExceedLimit"

	// 请求运营商加速超时。
	OPERATIONDENIED_REQUESTQOSTIMEOUT = "OperationDenied.RequestQosTimeout"

	// 该用户加速已取消,不处于加速状态。
	OPERATIONDENIED_USERNONACCELERATED = "OperationDenied.UserNonAccelerated"

	// 该用户不在运营商网络可加速范围内
	OPERATIONDENIED_USEROUTOFCOVERAGE = "OperationDenied.UserOutOfCoverage"

	// 运营商返回结果错误。
	OPERATIONDENIED_VENDORRETURNERROR = "OperationDenied.VendorReturnError"

	// 运营商服务器临时错误。
	OPERATIONDENIED_VENDORSERVERERROR = "OperationDenied.VendorServerError"

	// 请求的次数超过了频率限制。
	REQUESTLIMITEXCEEDED = "RequestLimitExceeded"

	// 资源不可用。
	RESOURCEUNAVAILABLE = "ResourceUnavailable"
)
const APIVersion = "2021-01-19"

Variables

This section is empty.

Functions

This section is empty.

Types

type AddDeviceRequest added in v1.0.496

type AddDeviceRequest struct {
	*tchttp.BaseRequest

	// 新建设备的名称
	DeviceName *string `json:"DeviceName,omitempty" name:"DeviceName"`

	// 新建设备的备注
	Remark *string `json:"Remark,omitempty" name:"Remark"`

	// 新建设备的base64密钥字符串,非必选,如果不填写则由系统自动生成
	DataKey *string `json:"DataKey,omitempty" name:"DataKey"`
}

func NewAddDeviceRequest added in v1.0.496

func NewAddDeviceRequest() (request *AddDeviceRequest)

func (*AddDeviceRequest) FromJsonString added in v1.0.496

func (r *AddDeviceRequest) FromJsonString(s string) error

FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check

func (*AddDeviceRequest) ToJsonString added in v1.0.496

func (r *AddDeviceRequest) ToJsonString() string

type AddDeviceRequestParams added in v1.0.496

type AddDeviceRequestParams struct {
	// 新建设备的名称
	DeviceName *string `json:"DeviceName,omitempty" name:"DeviceName"`

	// 新建设备的备注
	Remark *string `json:"Remark,omitempty" name:"Remark"`

	// 新建设备的base64密钥字符串,非必选,如果不填写则由系统自动生成
	DataKey *string `json:"DataKey,omitempty" name:"DataKey"`
}

Predefined struct for user

type AddDeviceResponse added in v1.0.496

type AddDeviceResponse struct {
	*tchttp.BaseResponse
	Response *AddDeviceResponseParams `json:"Response"`
}

func NewAddDeviceResponse added in v1.0.496

func NewAddDeviceResponse() (response *AddDeviceResponse)

func (*AddDeviceResponse) FromJsonString added in v1.0.496

func (r *AddDeviceResponse) FromJsonString(s string) error

FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check

func (*AddDeviceResponse) ToJsonString added in v1.0.496

func (r *AddDeviceResponse) ToJsonString() string

type AddDeviceResponseParams added in v1.0.496

type AddDeviceResponseParams struct {
	// 后台生成的base64字符串密钥
	DataKey *string `json:"DataKey,omitempty" name:"DataKey"`

	// 设备ID
	DeviceId *string `json:"DeviceId,omitempty" name:"DeviceId"`

	// 唯一请求 ID,每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
	RequestId *string `json:"RequestId,omitempty" name:"RequestId"`
}

Predefined struct for user

type Capacity

type Capacity struct {
	// 电信鉴权的Token。要加速的电信手机终端访问 http://qos.189.cn/qos-api/getToken?appid=TencentCloud 页面,获取返回结果中result的值
	CTCCToken *string `json:"CTCCToken,omitempty" name:"CTCCToken"`

	// 终端所处在的省份,建议不填写由服务端自动获取,若需填写请填写带有省、市、自治区、特别行政区等后缀的省份中文全称
	Province *string `json:"Province,omitempty" name:"Province"`
}

type Client

type Client struct {
	common.Client
}

func NewClient

func NewClient(credential common.CredentialIface, region string, clientProfile *profile.ClientProfile) (client *Client, err error)

func NewClientWithSecretId

func NewClientWithSecretId(secretId, secretKey, region string) (client *Client, err error)

Deprecated

func (*Client) AddDevice added in v1.0.496

func (c *Client) AddDevice(request *AddDeviceRequest) (response *AddDeviceResponse, err error)

AddDevice 新建设备记录

可能返回的错误码:

INTERNALERROR = "InternalError"
INTERNALERROR_CONTROLREQUESTERROR = "InternalError.ControlRequestError"
INVALIDPARAMETERVALUE = "InvalidParameterValue"

func (*Client) AddDeviceWithContext added in v1.0.496

func (c *Client) AddDeviceWithContext(ctx context.Context, request *AddDeviceRequest) (response *AddDeviceResponse, err error)

AddDevice 新建设备记录

可能返回的错误码:

INTERNALERROR = "InternalError"
INTERNALERROR_CONTROLREQUESTERROR = "InternalError.ControlRequestError"
INVALIDPARAMETERVALUE = "InvalidParameterValue"

func (*Client) CreateQos

func (c *Client) CreateQos(request *CreateQosRequest) (response *CreateQosResponse, err error)

CreateQos 移动网络发起Qos加速过程

可能返回的错误码:

INTERNALERROR = "InternalError"
INVALIDPARAMETER = "InvalidParameter"
INVALIDPARAMETERVALUE = "InvalidParameterValue"
INVALIDPARAMETERVALUE_VENDORNOTFOUND = "InvalidParameterValue.VendorNotFound"
MISSINGPARAMETER = "MissingParameter"
OPERATIONDENIED = "OperationDenied"
OPERATIONDENIED_ACCELERATIONNOTSUGGEST = "OperationDenied.AccelerationNotSuggest"
OPERATIONDENIED_CTCCTOKENEXPIRED = "OperationDenied.CTCCTokenExpired"
OPERATIONDENIED_CREATEQOSEXCEEDLIMIT = "OperationDenied.CreateQosExceedLimit"
OPERATIONDENIED_REQUESTQOSTIMEOUT = "OperationDenied.RequestQosTimeout"
OPERATIONDENIED_USEROUTOFCOVERAGE = "OperationDenied.UserOutOfCoverage"
OPERATIONDENIED_VENDORRETURNERROR = "OperationDenied.VendorReturnError"
OPERATIONDENIED_VENDORSERVERERROR = "OperationDenied.VendorServerError"
REQUESTLIMITEXCEEDED = "RequestLimitExceeded"
RESOURCEUNAVAILABLE = "ResourceUnavailable"

func (*Client) CreateQosWithContext added in v1.0.324

func (c *Client) CreateQosWithContext(ctx context.Context, request *CreateQosRequest) (response *CreateQosResponse, err error)

CreateQos 移动网络发起Qos加速过程

可能返回的错误码:

INTERNALERROR = "InternalError"
INVALIDPARAMETER = "InvalidParameter"
INVALIDPARAMETERVALUE = "InvalidParameterValue"
INVALIDPARAMETERVALUE_VENDORNOTFOUND = "InvalidParameterValue.VendorNotFound"
MISSINGPARAMETER = "MissingParameter"
OPERATIONDENIED = "OperationDenied"
OPERATIONDENIED_ACCELERATIONNOTSUGGEST = "OperationDenied.AccelerationNotSuggest"
OPERATIONDENIED_CTCCTOKENEXPIRED = "OperationDenied.CTCCTokenExpired"
OPERATIONDENIED_CREATEQOSEXCEEDLIMIT = "OperationDenied.CreateQosExceedLimit"
OPERATIONDENIED_REQUESTQOSTIMEOUT = "OperationDenied.RequestQosTimeout"
OPERATIONDENIED_USEROUTOFCOVERAGE = "OperationDenied.UserOutOfCoverage"
OPERATIONDENIED_VENDORRETURNERROR = "OperationDenied.VendorReturnError"
OPERATIONDENIED_VENDORSERVERERROR = "OperationDenied.VendorServerError"
REQUESTLIMITEXCEEDED = "RequestLimitExceeded"
RESOURCEUNAVAILABLE = "ResourceUnavailable"

func (*Client) DeleteDevice added in v1.0.496

func (c *Client) DeleteDevice(request *DeleteDeviceRequest) (response *DeleteDeviceResponse, err error)

DeleteDevice 删除设备信息

可能返回的错误码:

INTERNALERROR = "InternalError"
INTERNALERROR_CONTROLREQUESTERROR = "InternalError.ControlRequestError"
INVALIDPARAMETERVALUE = "InvalidParameterValue"

func (*Client) DeleteDeviceWithContext added in v1.0.496

func (c *Client) DeleteDeviceWithContext(ctx context.Context, request *DeleteDeviceRequest) (response *DeleteDeviceResponse, err error)

DeleteDevice 删除设备信息

可能返回的错误码:

INTERNALERROR = "InternalError"
INTERNALERROR_CONTROLREQUESTERROR = "InternalError.ControlRequestError"
INVALIDPARAMETERVALUE = "InvalidParameterValue"

func (*Client) DeleteQos

func (c *Client) DeleteQos(request *DeleteQosRequest) (response *DeleteQosResponse, err error)

DeleteQos 移动网络停止Qos加速过程

可能返回的错误码:

AUTHFAILURE = "AuthFailure"
INTERNALERROR = "InternalError"
INVALIDPARAMETER = "InvalidParameter"
INVALIDPARAMETERVALUE = "InvalidParameterValue"
MISSINGPARAMETER = "MissingParameter"
OPERATIONDENIED = "OperationDenied"
OPERATIONDENIED_REQUESTQOSTIMEOUT = "OperationDenied.RequestQosTimeout"
OPERATIONDENIED_USERNONACCELERATED = "OperationDenied.UserNonAccelerated"
OPERATIONDENIED_USEROUTOFCOVERAGE = "OperationDenied.UserOutOfCoverage"
OPERATIONDENIED_VENDORRETURNERROR = "OperationDenied.VendorReturnError"
OPERATIONDENIED_VENDORSERVERERROR = "OperationDenied.VendorServerError"

func (*Client) DeleteQosWithContext added in v1.0.324

func (c *Client) DeleteQosWithContext(ctx context.Context, request *DeleteQosRequest) (response *DeleteQosResponse, err error)

DeleteQos 移动网络停止Qos加速过程

可能返回的错误码:

AUTHFAILURE = "AuthFailure"
INTERNALERROR = "InternalError"
INVALIDPARAMETER = "InvalidParameter"
INVALIDPARAMETERVALUE = "InvalidParameterValue"
MISSINGPARAMETER = "MissingParameter"
OPERATIONDENIED = "OperationDenied"
OPERATIONDENIED_REQUESTQOSTIMEOUT = "OperationDenied.RequestQosTimeout"
OPERATIONDENIED_USERNONACCELERATED = "OperationDenied.UserNonAccelerated"
OPERATIONDENIED_USEROUTOFCOVERAGE = "OperationDenied.UserOutOfCoverage"
OPERATIONDENIED_VENDORRETURNERROR = "OperationDenied.VendorReturnError"
OPERATIONDENIED_VENDORSERVERERROR = "OperationDenied.VendorServerError"

func (*Client) DescribeQos added in v1.0.261

func (c *Client) DescribeQos(request *DescribeQosRequest) (response *DescribeQosResponse, err error)

DescribeQos 获取Qos加速状态

可能返回的错误码:

INTERNALERROR = "InternalError"
MISSINGPARAMETER = "MissingParameter"

func (*Client) DescribeQosWithContext added in v1.0.324

func (c *Client) DescribeQosWithContext(ctx context.Context, request *DescribeQosRequest) (response *DescribeQosResponse, err error)

DescribeQos 获取Qos加速状态

可能返回的错误码:

INTERNALERROR = "InternalError"
MISSINGPARAMETER = "MissingParameter"

func (*Client) GetDevice added in v1.0.496

func (c *Client) GetDevice(request *GetDeviceRequest) (response *GetDeviceResponse, err error)

GetDevice 通过指定设备的ID查找设备详细信息

可能返回的错误码:

INTERNALERROR = "InternalError"
INTERNALERROR_CONTROLREQUESTERROR = "InternalError.ControlRequestError"
INVALIDPARAMETERVALUE = "InvalidParameterValue"

func (*Client) GetDeviceWithContext added in v1.0.496

func (c *Client) GetDeviceWithContext(ctx context.Context, request *GetDeviceRequest) (response *GetDeviceResponse, err error)

GetDevice 通过指定设备的ID查找设备详细信息

可能返回的错误码:

INTERNALERROR = "InternalError"
INTERNALERROR_CONTROLREQUESTERROR = "InternalError.ControlRequestError"
INVALIDPARAMETERVALUE = "InvalidParameterValue"

func (*Client) GetDevices added in v1.0.496

func (c *Client) GetDevices(request *GetDevicesRequest) (response *GetDevicesResponse, err error)

GetDevices 获取设备信息列表

可能返回的错误码:

INTERNALERROR = "InternalError"
INTERNALERROR_CONTROLREQUESTERROR = "InternalError.ControlRequestError"
INVALIDPARAMETERVALUE = "InvalidParameterValue"

func (*Client) GetDevicesWithContext added in v1.0.496

func (c *Client) GetDevicesWithContext(ctx context.Context, request *GetDevicesRequest) (response *GetDevicesResponse, err error)

GetDevices 获取设备信息列表

可能返回的错误码:

INTERNALERROR = "InternalError"
INTERNALERROR_CONTROLREQUESTERROR = "InternalError.ControlRequestError"
INVALIDPARAMETERVALUE = "InvalidParameterValue"

func (*Client) GetFlowStatistic added in v1.0.497

func (c *Client) GetFlowStatistic(request *GetFlowStatisticRequest) (response *GetFlowStatisticResponse, err error)

GetFlowStatistic 获取指定设备Id,指定时间点数据流量使用情况

可能返回的错误码:

INTERNALERROR = "InternalError"
INTERNALERROR_NETWORKINFOREQUESTERROR = "InternalError.NetworkInfoRequestError"
INVALIDPARAMETERVALUE = "InvalidParameterValue"

func (*Client) GetFlowStatisticWithContext added in v1.0.497

func (c *Client) GetFlowStatisticWithContext(ctx context.Context, request *GetFlowStatisticRequest) (response *GetFlowStatisticResponse, err error)

GetFlowStatistic 获取指定设备Id,指定时间点数据流量使用情况

可能返回的错误码:

INTERNALERROR = "InternalError"
INTERNALERROR_NETWORKINFOREQUESTERROR = "InternalError.NetworkInfoRequestError"
INVALIDPARAMETERVALUE = "InvalidParameterValue"

func (*Client) GetStatisticData added in v1.0.496

func (c *Client) GetStatisticData(request *GetStatisticDataRequest) (response *GetStatisticDataResponse, err error)

GetStatisticData 在用量统计页面下载流量数据

可能返回的错误码:

INTERNALERROR = "InternalError"
INTERNALERROR_CONTROLREQUESTERROR = "InternalError.ControlRequestError"
INTERNALERROR_FILEIOERROR = "InternalError.FileIOError"
INTERNALERROR_NETWORKINFOREQUESTERROR = "InternalError.NetworkInfoRequestError"
INVALIDPARAMETER = "InvalidParameter"

func (*Client) GetStatisticDataWithContext added in v1.0.496

func (c *Client) GetStatisticDataWithContext(ctx context.Context, request *GetStatisticDataRequest) (response *GetStatisticDataResponse, err error)

GetStatisticData 在用量统计页面下载流量数据

可能返回的错误码:

INTERNALERROR = "InternalError"
INTERNALERROR_CONTROLREQUESTERROR = "InternalError.ControlRequestError"
INTERNALERROR_FILEIOERROR = "InternalError.FileIOError"
INTERNALERROR_NETWORKINFOREQUESTERROR = "InternalError.NetworkInfoRequestError"
INVALIDPARAMETER = "InvalidParameter"

func (*Client) UpdateDevice added in v1.0.496

func (c *Client) UpdateDevice(request *UpdateDeviceRequest) (response *UpdateDeviceResponse, err error)

UpdateDevice 更新设备信息

可能返回的错误码:

INTERNALERROR = "InternalError"
INTERNALERROR_CONTROLREQUESTERROR = "InternalError.ControlRequestError"
INVALIDPARAMETERVALUE = "InvalidParameterValue"

func (*Client) UpdateDeviceWithContext added in v1.0.496

func (c *Client) UpdateDeviceWithContext(ctx context.Context, request *UpdateDeviceRequest) (response *UpdateDeviceResponse, err error)

UpdateDevice 更新设备信息

可能返回的错误码:

INTERNALERROR = "InternalError"
INTERNALERROR_CONTROLREQUESTERROR = "InternalError.ControlRequestError"
INVALIDPARAMETERVALUE = "InvalidParameterValue"

type Context added in v1.0.351

type Context struct {
	// 测速数据
	NetworkData *NetworkData `json:"NetworkData,omitempty" name:"NetworkData"`

	// 用户期望最低门限
	ExpectedLowThreshold *ExpectedThreshold `json:"ExpectedLowThreshold,omitempty" name:"ExpectedLowThreshold"`

	// 用户期望最高门限
	ExpectedHighThreshold *ExpectedThreshold `json:"ExpectedHighThreshold,omitempty" name:"ExpectedHighThreshold"`
}

type CreateQosRequest

type CreateQosRequest struct {
	*tchttp.BaseRequest

	// 加速业务源地址信息,SrcIpv6和(SrcIpv4+SrcPublicIpv4)二选一,目前Ipv6不可用,全部填写以Ipv4参数为准。
	SrcAddressInfo *SrcAddressInfo `json:"SrcAddressInfo,omitempty" name:"SrcAddressInfo"`

	// 加速业务目标地址信息
	DestAddressInfo *DestAddressInfo `json:"DestAddressInfo,omitempty" name:"DestAddressInfo"`

	// 加速套餐
	// T100K:时延性保障 + 带宽保障上下行保障 100kbps
	// T200K:时延性保障 + 带宽保障上下行保障 200kbps
	// T400K:时延性保障 + 带宽保障上下行保障  400kbps
	// BD1M:带宽型保障 + 下行带宽保障1Mbps
	// BD2M:带宽型保障 + 下行带宽保障2Mbps
	// BD4M:带宽型保障 + 下行带宽保障4Mbps
	// BU1M:带宽型保障 + 上行带宽保障1Mbps
	// BU2M:带宽型保障 + 上行带宽保障2Mbps
	// BU4M:带宽型保障 + 上行带宽保障4Mbps
	QosMenu *string `json:"QosMenu,omitempty" name:"QosMenu"`

	// 申请加速的设备信息,包括运营商,操作系统,设备唯一标识等。
	DeviceInfo *DeviceInfo `json:"DeviceInfo,omitempty" name:"DeviceInfo"`

	// 期望加速时长(单位分钟),默认值30分钟
	Duration *uint64 `json:"Duration,omitempty" name:"Duration"`

	// 接口能力扩展,如果是电信用户,必须填充CTCC Token字段
	Capacity *Capacity `json:"Capacity,omitempty" name:"Capacity"`

	// 应用模板ID
	TemplateId *string `json:"TemplateId,omitempty" name:"TemplateId"`

	// 针对特殊协议进行加速
	// 1. IP (默认值)
	// 2. UDP
	// 3. TCP
	Protocol *uint64 `json:"Protocol,omitempty" name:"Protocol"`

	// 加速策略关键数据
	Context *Context `json:"Context,omitempty" name:"Context"`

	// 签名
	Extern *string `json:"Extern,omitempty" name:"Extern"`
}

func NewCreateQosRequest

func NewCreateQosRequest() (request *CreateQosRequest)

func (*CreateQosRequest) FromJsonString

func (r *CreateQosRequest) FromJsonString(s string) error

FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check

func (*CreateQosRequest) ToJsonString

func (r *CreateQosRequest) ToJsonString() string

type CreateQosRequestParams added in v1.0.426

type CreateQosRequestParams struct {
	// 加速业务源地址信息,SrcIpv6和(SrcIpv4+SrcPublicIpv4)二选一,目前Ipv6不可用,全部填写以Ipv4参数为准。
	SrcAddressInfo *SrcAddressInfo `json:"SrcAddressInfo,omitempty" name:"SrcAddressInfo"`

	// 加速业务目标地址信息
	DestAddressInfo *DestAddressInfo `json:"DestAddressInfo,omitempty" name:"DestAddressInfo"`

	// 加速套餐
	// T100K:时延性保障 + 带宽保障上下行保障 100kbps
	// T200K:时延性保障 + 带宽保障上下行保障 200kbps
	// T400K:时延性保障 + 带宽保障上下行保障  400kbps
	// BD1M:带宽型保障 + 下行带宽保障1Mbps
	// BD2M:带宽型保障 + 下行带宽保障2Mbps
	// BD4M:带宽型保障 + 下行带宽保障4Mbps
	// BU1M:带宽型保障 + 上行带宽保障1Mbps
	// BU2M:带宽型保障 + 上行带宽保障2Mbps
	// BU4M:带宽型保障 + 上行带宽保障4Mbps
	QosMenu *string `json:"QosMenu,omitempty" name:"QosMenu"`

	// 申请加速的设备信息,包括运营商,操作系统,设备唯一标识等。
	DeviceInfo *DeviceInfo `json:"DeviceInfo,omitempty" name:"DeviceInfo"`

	// 期望加速时长(单位分钟),默认值30分钟
	Duration *uint64 `json:"Duration,omitempty" name:"Duration"`

	// 接口能力扩展,如果是电信用户,必须填充CTCC Token字段
	Capacity *Capacity `json:"Capacity,omitempty" name:"Capacity"`

	// 应用模板ID
	TemplateId *string `json:"TemplateId,omitempty" name:"TemplateId"`

	// 针对特殊协议进行加速
	// 1. IP (默认值)
	// 2. UDP
	// 3. TCP
	Protocol *uint64 `json:"Protocol,omitempty" name:"Protocol"`

	// 加速策略关键数据
	Context *Context `json:"Context,omitempty" name:"Context"`

	// 签名
	Extern *string `json:"Extern,omitempty" name:"Extern"`
}

Predefined struct for user

type CreateQosResponse

type CreateQosResponse struct {
	*tchttp.BaseResponse
	Response *CreateQosResponseParams `json:"Response"`
}

func NewCreateQosResponse

func NewCreateQosResponse() (response *CreateQosResponse)

func (*CreateQosResponse) FromJsonString

func (r *CreateQosResponse) FromJsonString(s string) error

FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check

func (*CreateQosResponse) ToJsonString

func (r *CreateQosResponse) ToJsonString() string

type CreateQosResponseParams added in v1.0.426

type CreateQosResponseParams struct {
	// 单次加速唯一 Id
	SessionId *string `json:"SessionId,omitempty" name:"SessionId"`

	// 当前加速剩余时长(单位秒)
	Duration *uint64 `json:"Duration,omitempty" name:"Duration"`

	// 唯一请求 ID,每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
	RequestId *string `json:"RequestId,omitempty" name:"RequestId"`
}

Predefined struct for user

type DeleteDeviceRequest added in v1.0.496

type DeleteDeviceRequest struct {
	*tchttp.BaseRequest

	// 删除设备的唯一ID
	DeviceId *string `json:"DeviceId,omitempty" name:"DeviceId"`
}

func NewDeleteDeviceRequest added in v1.0.496

func NewDeleteDeviceRequest() (request *DeleteDeviceRequest)

func (*DeleteDeviceRequest) FromJsonString added in v1.0.496

func (r *DeleteDeviceRequest) FromJsonString(s string) error

FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check

func (*DeleteDeviceRequest) ToJsonString added in v1.0.496

func (r *DeleteDeviceRequest) ToJsonString() string

type DeleteDeviceRequestParams added in v1.0.496

type DeleteDeviceRequestParams struct {
	// 删除设备的唯一ID
	DeviceId *string `json:"DeviceId,omitempty" name:"DeviceId"`
}

Predefined struct for user

type DeleteDeviceResponse added in v1.0.496

type DeleteDeviceResponse struct {
	*tchttp.BaseResponse
	Response *DeleteDeviceResponseParams `json:"Response"`
}

func NewDeleteDeviceResponse added in v1.0.496

func NewDeleteDeviceResponse() (response *DeleteDeviceResponse)

func (*DeleteDeviceResponse) FromJsonString added in v1.0.496

func (r *DeleteDeviceResponse) FromJsonString(s string) error

FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check

func (*DeleteDeviceResponse) ToJsonString added in v1.0.496

func (r *DeleteDeviceResponse) ToJsonString() string

type DeleteDeviceResponseParams added in v1.0.496

type DeleteDeviceResponseParams struct {
	// 唯一请求 ID,每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
	RequestId *string `json:"RequestId,omitempty" name:"RequestId"`
}

Predefined struct for user

type DeleteQosRequest

type DeleteQosRequest struct {
	*tchttp.BaseRequest

	// 单次加速唯一 Id
	SessionId *string `json:"SessionId,omitempty" name:"SessionId"`
}

func NewDeleteQosRequest

func NewDeleteQosRequest() (request *DeleteQosRequest)

func (*DeleteQosRequest) FromJsonString

func (r *DeleteQosRequest) FromJsonString(s string) error

FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check

func (*DeleteQosRequest) ToJsonString

func (r *DeleteQosRequest) ToJsonString() string

type DeleteQosRequestParams added in v1.0.426

type DeleteQosRequestParams struct {
	// 单次加速唯一 Id
	SessionId *string `json:"SessionId,omitempty" name:"SessionId"`
}

Predefined struct for user

type DeleteQosResponse

type DeleteQosResponse struct {
	*tchttp.BaseResponse
	Response *DeleteQosResponseParams `json:"Response"`
}

func NewDeleteQosResponse

func NewDeleteQosResponse() (response *DeleteQosResponse)

func (*DeleteQosResponse) FromJsonString

func (r *DeleteQosResponse) FromJsonString(s string) error

FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check

func (*DeleteQosResponse) ToJsonString

func (r *DeleteQosResponse) ToJsonString() string

type DeleteQosResponseParams added in v1.0.426

type DeleteQosResponseParams struct {
	// 单次加速唯一 Id
	SessionId *string `json:"SessionId,omitempty" name:"SessionId"`

	// 本次加速会话持续时间(单位秒)
	Duration *uint64 `json:"Duration,omitempty" name:"Duration"`

	// 唯一请求 ID,每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
	RequestId *string `json:"RequestId,omitempty" name:"RequestId"`
}

Predefined struct for user

type DescribeQosRequest added in v1.0.261

type DescribeQosRequest struct {
	*tchttp.BaseRequest

	// 单次加速唯一 Id
	SessionId *string `json:"SessionId,omitempty" name:"SessionId"`
}

func NewDescribeQosRequest added in v1.0.261

func NewDescribeQosRequest() (request *DescribeQosRequest)

func (*DescribeQosRequest) FromJsonString added in v1.0.261

func (r *DescribeQosRequest) FromJsonString(s string) error

FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check

func (*DescribeQosRequest) ToJsonString added in v1.0.261

func (r *DescribeQosRequest) ToJsonString() string

type DescribeQosRequestParams added in v1.0.426

type DescribeQosRequestParams struct {
	// 单次加速唯一 Id
	SessionId *string `json:"SessionId,omitempty" name:"SessionId"`
}

Predefined struct for user

type DescribeQosResponse added in v1.0.261

type DescribeQosResponse struct {
	*tchttp.BaseResponse
	Response *DescribeQosResponseParams `json:"Response"`
}

func NewDescribeQosResponse added in v1.0.261

func NewDescribeQosResponse() (response *DescribeQosResponse)

func (*DescribeQosResponse) FromJsonString added in v1.0.261

func (r *DescribeQosResponse) FromJsonString(s string) error

FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check

func (*DescribeQosResponse) ToJsonString added in v1.0.261

func (r *DescribeQosResponse) ToJsonString() string

type DescribeQosResponseParams added in v1.0.426

type DescribeQosResponseParams struct {
	// 0:无匹配的加速中会话
	// 1:存在匹配的加速中会话
	Status *uint64 `json:"Status,omitempty" name:"Status"`

	// 手机公网出口IP,仅匹配时返回
	// 注意:此字段可能返回 null,表示取不到有效值。
	SrcPublicIpv4 *string `json:"SrcPublicIpv4,omitempty" name:"SrcPublicIpv4"`

	// 业务访问目的IP,仅匹配时返回
	// 注意:此字段可能返回 null,表示取不到有效值。
	DestIpv4 []*string `json:"DestIpv4,omitempty" name:"DestIpv4"`

	// 当前加速剩余时长(单位秒)有,仅匹配时返回
	// 注意:此字段可能返回 null,表示取不到有效值。
	Duration *uint64 `json:"Duration,omitempty" name:"Duration"`

	// 加速套餐类型,仅匹配时返回
	// 注意:此字段可能返回 null,表示取不到有效值。
	QosMenu *string `json:"QosMenu,omitempty" name:"QosMenu"`

	// 唯一请求 ID,每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
	RequestId *string `json:"RequestId,omitempty" name:"RequestId"`
}

Predefined struct for user

type DestAddressInfo

type DestAddressInfo struct {
	// 加速业务目标 ip 地址数组
	DestIp []*string `json:"DestIp,omitempty" name:"DestIp"`
}

type DeviceBaseInfo added in v1.0.496

type DeviceBaseInfo struct {
	// 设备唯一ID
	DeviceId *string `json:"DeviceId,omitempty" name:"DeviceId"`

	// 设备名称
	DeviceName *string `json:"DeviceName,omitempty" name:"DeviceName"`

	// 设备创建的时间,单位:ms
	CreateTime *string `json:"CreateTime,omitempty" name:"CreateTime"`

	// 设备最后在线时间,单位:ms
	LastTime *string `json:"LastTime,omitempty" name:"LastTime"`

	// 设备的备注
	Remark *string `json:"Remark,omitempty" name:"Remark"`
}

type DeviceDetails added in v1.0.496

type DeviceDetails struct {
	// 设备基本信息
	DeviceBaseInfo *DeviceBaseInfo `json:"DeviceBaseInfo,omitempty" name:"DeviceBaseInfo"`

	// 设备网络信息
	// 注意:此字段可能返回 null,表示取不到有效值。
	DeviceNetInfo []*DeviceNetInfo `json:"DeviceNetInfo,omitempty" name:"DeviceNetInfo"`
}

type DeviceInfo

type DeviceInfo struct {
	// 运营商
	// 1:移动
	// 2:电信
	// 3:联通
	// 4:广电
	// 99:其他
	Vendor *uint64 `json:"Vendor,omitempty" name:"Vendor"`

	// 设备操作系统:
	// 1:Android
	// 2: IOS
	// 99:其他
	OS *uint64 `json:"OS,omitempty" name:"OS"`

	// 设备唯一标识
	// IOS 填写 IDFV
	// Android 填写 IMEI
	DeviceId *string `json:"DeviceId,omitempty" name:"DeviceId"`

	// 用户手机号码
	PhoneNum *string `json:"PhoneNum,omitempty" name:"PhoneNum"`

	// 无线信息
	// 1:4G
	// 2:5G
	// 3:WIFI
	// 99:其他
	Wireless *uint64 `json:"Wireless,omitempty" name:"Wireless"`
}

type DeviceNetInfo added in v1.0.496

type DeviceNetInfo struct {
	// 网络类型:
	// 0:数据
	// 1:Wi-Fi
	// 2:有线
	// 注意:此字段可能返回 null,表示取不到有效值。
	Type *int64 `json:"Type,omitempty" name:"Type"`

	// 启用/禁用
	// 注意:此字段可能返回 null,表示取不到有效值。
	DataEnable *bool `json:"DataEnable,omitempty" name:"DataEnable"`

	// 上行限速
	// 注意:此字段可能返回 null,表示取不到有效值。
	UploadLimit *string `json:"UploadLimit,omitempty" name:"UploadLimit"`

	// 下行限速
	// 注意:此字段可能返回 null,表示取不到有效值。
	DownloadLimit *string `json:"DownloadLimit,omitempty" name:"DownloadLimit"`

	// 接收实时速率
	// 注意:此字段可能返回 null,表示取不到有效值。
	DataRx *uint64 `json:"DataRx,omitempty" name:"DataRx"`

	// 发送实时速率
	// 注意:此字段可能返回 null,表示取不到有效值。
	DataTx *uint64 `json:"DataTx,omitempty" name:"DataTx"`

	// 运营商类型:
	// 1: 中国移动;
	// 2: 中国电信;
	// 3: 中国联通
	// 注意:此字段可能返回 null,表示取不到有效值。
	Vendor *int64 `json:"Vendor,omitempty" name:"Vendor"`

	// 连接状态:
	// 0:无连接
	// 1:连接中
	// 2:已连接
	// 注意:此字段可能返回 null,表示取不到有效值。
	State *int64 `json:"State,omitempty" name:"State"`

	// 公网IP
	// 注意:此字段可能返回 null,表示取不到有效值。
	PublicIp *string `json:"PublicIp,omitempty" name:"PublicIp"`

	// 信号强度/单位:dbm
	// 注意:此字段可能返回 null,表示取不到有效值。
	SignalStrength *int64 `json:"SignalStrength,omitempty" name:"SignalStrength"`

	// 数据网络类型:
	// -1 :无效值
	// 2:2G
	// 3:3G
	// 4:4G
	// 5:5G
	// 注意:此字段可能返回 null,表示取不到有效值。
	Rat *int64 `json:"Rat,omitempty" name:"Rat"`

	// 网卡名
	// 注意:此字段可能返回 null,表示取不到有效值。
	NetInfoName *string `json:"NetInfoName,omitempty" name:"NetInfoName"`
}

type ExpectedThreshold added in v1.0.351

type ExpectedThreshold struct {
	// 期望发起加速的时延阈值
	RTT *float64 `json:"RTT,omitempty" name:"RTT"`

	// 期望发起加速的丢包率阈值
	Loss *float64 `json:"Loss,omitempty" name:"Loss"`

	// 期望发起加速的抖动阈值
	Jitter *float64 `json:"Jitter,omitempty" name:"Jitter"`
}

type GetDeviceRequest added in v1.0.496

type GetDeviceRequest struct {
	*tchttp.BaseRequest

	// 搜索指定设备的id
	DeviceId *string `json:"DeviceId,omitempty" name:"DeviceId"`
}

func NewGetDeviceRequest added in v1.0.496

func NewGetDeviceRequest() (request *GetDeviceRequest)

func (*GetDeviceRequest) FromJsonString added in v1.0.496

func (r *GetDeviceRequest) FromJsonString(s string) error

FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check

func (*GetDeviceRequest) ToJsonString added in v1.0.496

func (r *GetDeviceRequest) ToJsonString() string

type GetDeviceRequestParams added in v1.0.496

type GetDeviceRequestParams struct {
	// 搜索指定设备的id
	DeviceId *string `json:"DeviceId,omitempty" name:"DeviceId"`
}

Predefined struct for user

type GetDeviceResponse added in v1.0.496

type GetDeviceResponse struct {
	*tchttp.BaseResponse
	Response *GetDeviceResponseParams `json:"Response"`
}

func NewGetDeviceResponse added in v1.0.496

func NewGetDeviceResponse() (response *GetDeviceResponse)

func (*GetDeviceResponse) FromJsonString added in v1.0.496

func (r *GetDeviceResponse) FromJsonString(s string) error

FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check

func (*GetDeviceResponse) ToJsonString added in v1.0.496

func (r *GetDeviceResponse) ToJsonString() string

type GetDeviceResponseParams added in v1.0.496

type GetDeviceResponseParams struct {
	// 设备详细信息
	DeviceDetails *DeviceDetails `json:"DeviceDetails,omitempty" name:"DeviceDetails"`

	// 唯一请求 ID,每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
	RequestId *string `json:"RequestId,omitempty" name:"RequestId"`
}

Predefined struct for user

type GetDevicesRequest added in v1.0.496

type GetDevicesRequest struct {
	*tchttp.BaseRequest

	// 每页显示记录数,PageSize、PageNumber值均为-1 时,按照1页无限制条数匹配所有设备
	PageSize *int64 `json:"PageSize,omitempty" name:"PageSize"`

	// 当前查看页码,PageSize、PageNumber值均为-1 时,按照1页无限制条数匹配所有设备
	PageNumber *int64 `json:"PageNumber,omitempty" name:"PageNumber"`

	// 搜索设备的关键字(ID或者设备名),为空时匹配所有设备
	Keyword *string `json:"Keyword,omitempty" name:"Keyword"`
}

func NewGetDevicesRequest added in v1.0.496

func NewGetDevicesRequest() (request *GetDevicesRequest)

func (*GetDevicesRequest) FromJsonString added in v1.0.496

func (r *GetDevicesRequest) FromJsonString(s string) error

FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check

func (*GetDevicesRequest) ToJsonString added in v1.0.496

func (r *GetDevicesRequest) ToJsonString() string

type GetDevicesRequestParams added in v1.0.496

type GetDevicesRequestParams struct {
	// 每页显示记录数,PageSize、PageNumber值均为-1 时,按照1页无限制条数匹配所有设备
	PageSize *int64 `json:"PageSize,omitempty" name:"PageSize"`

	// 当前查看页码,PageSize、PageNumber值均为-1 时,按照1页无限制条数匹配所有设备
	PageNumber *int64 `json:"PageNumber,omitempty" name:"PageNumber"`

	// 搜索设备的关键字(ID或者设备名),为空时匹配所有设备
	Keyword *string `json:"Keyword,omitempty" name:"Keyword"`
}

Predefined struct for user

type GetDevicesResponse added in v1.0.496

type GetDevicesResponse struct {
	*tchttp.BaseResponse
	Response *GetDevicesResponseParams `json:"Response"`
}

func NewGetDevicesResponse added in v1.0.496

func NewGetDevicesResponse() (response *GetDevicesResponse)

func (*GetDevicesResponse) FromJsonString added in v1.0.496

func (r *GetDevicesResponse) FromJsonString(s string) error

FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check

func (*GetDevicesResponse) ToJsonString added in v1.0.496

func (r *GetDevicesResponse) ToJsonString() string

type GetDevicesResponseParams added in v1.0.496

type GetDevicesResponseParams struct {
	// 设备信息列表
	DeviceInfos []*DeviceBaseInfo `json:"DeviceInfos,omitempty" name:"DeviceInfos"`

	// 设备总记录条数
	Length *int64 `json:"Length,omitempty" name:"Length"`

	// 总页数
	TotalPage *int64 `json:"TotalPage,omitempty" name:"TotalPage"`

	// 唯一请求 ID,每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
	RequestId *string `json:"RequestId,omitempty" name:"RequestId"`
}

Predefined struct for user

type GetFlowStatisticRequest added in v1.0.497

type GetFlowStatisticRequest struct {
	*tchttp.BaseRequest

	// 设备ID,ID="-1"时默认查找所有设备
	DeviceId *string `json:"DeviceId,omitempty" name:"DeviceId"`

	// 开始查找时间
	BeginTime *int64 `json:"BeginTime,omitempty" name:"BeginTime"`

	// 截止时间
	EndTime *int64 `json:"EndTime,omitempty" name:"EndTime"`

	// 流量种类(1:上行流量,2:下行流量)
	Type *int64 `json:"Type,omitempty" name:"Type"`

	// 时间粒度(1:按小时统计,2:按天统计)
	TimeGranularity *int64 `json:"TimeGranularity,omitempty" name:"TimeGranularity"`
}

func NewGetFlowStatisticRequest added in v1.0.497

func NewGetFlowStatisticRequest() (request *GetFlowStatisticRequest)

func (*GetFlowStatisticRequest) FromJsonString added in v1.0.497

func (r *GetFlowStatisticRequest) FromJsonString(s string) error

FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check

func (*GetFlowStatisticRequest) ToJsonString added in v1.0.497

func (r *GetFlowStatisticRequest) ToJsonString() string

type GetFlowStatisticRequestParams added in v1.0.497

type GetFlowStatisticRequestParams struct {
	// 设备ID,ID="-1"时默认查找所有设备
	DeviceId *string `json:"DeviceId,omitempty" name:"DeviceId"`

	// 开始查找时间
	BeginTime *int64 `json:"BeginTime,omitempty" name:"BeginTime"`

	// 截止时间
	EndTime *int64 `json:"EndTime,omitempty" name:"EndTime"`

	// 流量种类(1:上行流量,2:下行流量)
	Type *int64 `json:"Type,omitempty" name:"Type"`

	// 时间粒度(1:按小时统计,2:按天统计)
	TimeGranularity *int64 `json:"TimeGranularity,omitempty" name:"TimeGranularity"`
}

Predefined struct for user

type GetFlowStatisticResponse added in v1.0.497

type GetFlowStatisticResponse struct {
	*tchttp.BaseResponse
	Response *GetFlowStatisticResponseParams `json:"Response"`
}

func NewGetFlowStatisticResponse added in v1.0.497

func NewGetFlowStatisticResponse() (response *GetFlowStatisticResponse)

func (*GetFlowStatisticResponse) FromJsonString added in v1.0.497

func (r *GetFlowStatisticResponse) FromJsonString(s string) error

FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check

func (*GetFlowStatisticResponse) ToJsonString added in v1.0.497

func (r *GetFlowStatisticResponse) ToJsonString() string

type GetFlowStatisticResponseParams added in v1.0.497

type GetFlowStatisticResponseParams struct {
	// 流量详细信息
	NetDetails []*NetDetails `json:"NetDetails,omitempty" name:"NetDetails"`

	// 查找时间段流量使用最大值(单位:bit)
	MaxValue *float64 `json:"MaxValue,omitempty" name:"MaxValue"`

	// 查找时间段流量使用平均值(单位:bit)
	AvgValue *float64 `json:"AvgValue,omitempty" name:"AvgValue"`

	// 查找时间段流量使用总量(单位:bit)
	TotalValue *float64 `json:"TotalValue,omitempty" name:"TotalValue"`

	// 唯一请求 ID,每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
	RequestId *string `json:"RequestId,omitempty" name:"RequestId"`
}

Predefined struct for user

type GetStatisticDataRequest added in v1.0.496

type GetStatisticDataRequest struct {
	*tchttp.BaseRequest

	// 设备ID,设备ID="-1"获取所有设备流量统计
	DeviceId *string `json:"DeviceId,omitempty" name:"DeviceId"`

	// 统计开始时间,单位:s
	BeginTime *int64 `json:"BeginTime,omitempty" name:"BeginTime"`

	// 统计结束时间,单位:s
	EndTime *int64 `json:"EndTime,omitempty" name:"EndTime"`

	// 聚合粒度:
	// 1:按小时统计
	// 2:按天统计
	TimeGranularity *int64 `json:"TimeGranularity,omitempty" name:"TimeGranularity"`
}

func NewGetStatisticDataRequest added in v1.0.496

func NewGetStatisticDataRequest() (request *GetStatisticDataRequest)

func (*GetStatisticDataRequest) FromJsonString added in v1.0.496

func (r *GetStatisticDataRequest) FromJsonString(s string) error

FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check

func (*GetStatisticDataRequest) ToJsonString added in v1.0.496

func (r *GetStatisticDataRequest) ToJsonString() string

type GetStatisticDataRequestParams added in v1.0.496

type GetStatisticDataRequestParams struct {
	// 设备ID,设备ID="-1"获取所有设备流量统计
	DeviceId *string `json:"DeviceId,omitempty" name:"DeviceId"`

	// 统计开始时间,单位:s
	BeginTime *int64 `json:"BeginTime,omitempty" name:"BeginTime"`

	// 统计结束时间,单位:s
	EndTime *int64 `json:"EndTime,omitempty" name:"EndTime"`

	// 聚合粒度:
	// 1:按小时统计
	// 2:按天统计
	TimeGranularity *int64 `json:"TimeGranularity,omitempty" name:"TimeGranularity"`
}

Predefined struct for user

type GetStatisticDataResponse added in v1.0.496

type GetStatisticDataResponse struct {
	*tchttp.BaseResponse
	Response *GetStatisticDataResponseParams `json:"Response"`
}

func NewGetStatisticDataResponse added in v1.0.496

func NewGetStatisticDataResponse() (response *GetStatisticDataResponse)

func (*GetStatisticDataResponse) FromJsonString added in v1.0.496

func (r *GetStatisticDataResponse) FromJsonString(s string) error

FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check

func (*GetStatisticDataResponse) ToJsonString added in v1.0.496

func (r *GetStatisticDataResponse) ToJsonString() string

type GetStatisticDataResponseParams added in v1.0.496

type GetStatisticDataResponseParams struct {
	// 文件地址url
	FilePath *string `json:"FilePath,omitempty" name:"FilePath"`

	// 唯一请求 ID,每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
	RequestId *string `json:"RequestId,omitempty" name:"RequestId"`
}

Predefined struct for user

type NetDetails added in v1.0.497

type NetDetails struct {
	// 时间点,单位:s
	Time *string `json:"Time,omitempty" name:"Time"`

	// 流量值(bit)
	Current *float64 `json:"Current,omitempty" name:"Current"`
}

type NetworkData added in v1.0.351

type NetworkData struct {
	// 时延数组,最大长度30
	RTT []*float64 `json:"RTT,omitempty" name:"RTT"`

	// 丢包率
	Loss *float64 `json:"Loss,omitempty" name:"Loss"`

	// 抖动
	Jitter *float64 `json:"Jitter,omitempty" name:"Jitter"`

	// 10位秒级时间戳
	Timestamp *int64 `json:"Timestamp,omitempty" name:"Timestamp"`
}

type SrcAddressInfo

type SrcAddressInfo struct {
	// 用户私网 ipv4 地址
	SrcIpv4 *string `json:"SrcIpv4,omitempty" name:"SrcIpv4"`

	// 用户公网 ipv4 地址
	SrcPublicIpv4 *string `json:"SrcPublicIpv4,omitempty" name:"SrcPublicIpv4"`

	// 用户 ipv6 地址
	SrcIpv6 *string `json:"SrcIpv6,omitempty" name:"SrcIpv6"`
}

type UpdateDeviceRequest added in v1.0.496

type UpdateDeviceRequest struct {
	*tchttp.BaseRequest

	// 设备id
	DeviceId *string `json:"DeviceId,omitempty" name:"DeviceId"`

	// 设备名称
	DeviceName *string `json:"DeviceName,omitempty" name:"DeviceName"`

	// 设备备注
	Remark *string `json:"Remark,omitempty" name:"Remark"`

	// 更新设备网络信息
	UpdateNetInfo []*UpdateNetInfo `json:"UpdateNetInfo,omitempty" name:"UpdateNetInfo"`
}

func NewUpdateDeviceRequest added in v1.0.496

func NewUpdateDeviceRequest() (request *UpdateDeviceRequest)

func (*UpdateDeviceRequest) FromJsonString added in v1.0.496

func (r *UpdateDeviceRequest) FromJsonString(s string) error

FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check

func (*UpdateDeviceRequest) ToJsonString added in v1.0.496

func (r *UpdateDeviceRequest) ToJsonString() string

type UpdateDeviceRequestParams added in v1.0.496

type UpdateDeviceRequestParams struct {
	// 设备id
	DeviceId *string `json:"DeviceId,omitempty" name:"DeviceId"`

	// 设备名称
	DeviceName *string `json:"DeviceName,omitempty" name:"DeviceName"`

	// 设备备注
	Remark *string `json:"Remark,omitempty" name:"Remark"`

	// 更新设备网络信息
	UpdateNetInfo []*UpdateNetInfo `json:"UpdateNetInfo,omitempty" name:"UpdateNetInfo"`
}

Predefined struct for user

type UpdateDeviceResponse added in v1.0.496

type UpdateDeviceResponse struct {
	*tchttp.BaseResponse
	Response *UpdateDeviceResponseParams `json:"Response"`
}

func NewUpdateDeviceResponse added in v1.0.496

func NewUpdateDeviceResponse() (response *UpdateDeviceResponse)

func (*UpdateDeviceResponse) FromJsonString added in v1.0.496

func (r *UpdateDeviceResponse) FromJsonString(s string) error

FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check

func (*UpdateDeviceResponse) ToJsonString added in v1.0.496

func (r *UpdateDeviceResponse) ToJsonString() string

type UpdateDeviceResponseParams added in v1.0.496

type UpdateDeviceResponseParams struct {
	// 唯一请求 ID,每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
	RequestId *string `json:"RequestId,omitempty" name:"RequestId"`
}

Predefined struct for user

type UpdateNetInfo added in v1.0.496

type UpdateNetInfo struct {
	// 网络类型:
	// 0:数据
	// 1:Wi-Fi
	Type *int64 `json:"Type,omitempty" name:"Type"`

	// 启用/禁用
	DataEnable *bool `json:"DataEnable,omitempty" name:"DataEnable"`

	// 上行限速:bit
	UploadLimit *uint64 `json:"UploadLimit,omitempty" name:"UploadLimit"`

	// 下行限速:bit
	DownloadLimit *uint64 `json:"DownloadLimit,omitempty" name:"DownloadLimit"`

	// 网卡名
	NetInfoName *string `json:"NetInfoName,omitempty" name:"NetInfoName"`
}

Jump to