Documentation
¶
Index ¶
Constants ¶
const ( // 内部错误。 INTERNALERROR = "InternalError" // 参数错误。 INVALIDPARAMETER = "InvalidParameter" // 参数取值错误。 INVALIDPARAMETERVALUE = "InvalidParameterValue" )
const APIVersion = "2023-03-06"
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
func NewClient ¶
func NewClient(credential common.CredentialIface, region string, clientProfile *profile.ClientProfile) (client *Client, err error)
func NewClientWithSecretId ¶
Deprecated
func (*Client) DescribeEvents ¶
func (c *Client) DescribeEvents(request *DescribeEventsRequest) (response *DescribeEventsResponse, err error)
DescribeEvents 本接口用于查询腾讯云健康看板的可用性事件信息,可以通过产品列表、地域列表和事件发生日期进行过滤查询。
可能返回的错误码:
INTERNALERROR = "InternalError" INVALIDPARAMETER = "InvalidParameter" INVALIDPARAMETERVALUE = "InvalidParameterValue"
func (*Client) DescribeEventsWithContext ¶
func (c *Client) DescribeEventsWithContext(ctx context.Context, request *DescribeEventsRequest) (response *DescribeEventsResponse, err error)
DescribeEvents 本接口用于查询腾讯云健康看板的可用性事件信息,可以通过产品列表、地域列表和事件发生日期进行过滤查询。
可能返回的错误码:
INTERNALERROR = "InternalError" INVALIDPARAMETER = "InvalidParameter" INVALIDPARAMETERVALUE = "InvalidParameterValue"
type DescribeEventsRequest ¶
type DescribeEventsRequest struct {
*tchttp.BaseRequest
// 事件的发生日期
EventDate *string `json:"EventDate,omitempty" name:"EventDate"`
// 1. 不指定产品列表时将查询所有产品。
// 2. 产品ID示例:cvm、lb、cdb、cdn、crs
ProductIds []*string `json:"ProductIds,omitempty" name:"ProductIds"`
// 1. 不指定地域列表时将查询所有地域。
// 2. 查询非区域性产品事件时,地域ID指定为:non-regional
// 3. 其他地域ID取值请参考:https://cloud.tencent.com/document/api/213/15692
RegionIds []*string `json:"RegionIds,omitempty" name:"RegionIds"`
}
func NewDescribeEventsRequest ¶
func NewDescribeEventsRequest() (request *DescribeEventsRequest)
func (*DescribeEventsRequest) FromJsonString ¶
func (r *DescribeEventsRequest) FromJsonString(s string) error
FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check
func (*DescribeEventsRequest) ToJsonString ¶
func (r *DescribeEventsRequest) ToJsonString() string
type DescribeEventsRequestParams ¶
type DescribeEventsRequestParams struct {
// 事件的发生日期
EventDate *string `json:"EventDate,omitempty" name:"EventDate"`
// 1. 不指定产品列表时将查询所有产品。
// 2. 产品ID示例:cvm、lb、cdb、cdn、crs
ProductIds []*string `json:"ProductIds,omitempty" name:"ProductIds"`
// 1. 不指定地域列表时将查询所有地域。
// 2. 查询非区域性产品事件时,地域ID指定为:non-regional
// 3. 其他地域ID取值请参考:https://cloud.tencent.com/document/api/213/15692
RegionIds []*string `json:"RegionIds,omitempty" name:"RegionIds"`
}
Predefined struct for user
type DescribeEventsResponse ¶
type DescribeEventsResponse struct {
*tchttp.BaseResponse
Response *DescribeEventsResponseParams `json:"Response"`
}
func NewDescribeEventsResponse ¶
func NewDescribeEventsResponse() (response *DescribeEventsResponse)
func (*DescribeEventsResponse) FromJsonString ¶
func (r *DescribeEventsResponse) FromJsonString(s string) error
FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check
func (*DescribeEventsResponse) ToJsonString ¶
func (r *DescribeEventsResponse) ToJsonString() string
type DescribeEventsResponseParams ¶
type DescribeEventsResponseParams struct {
// 事件详情列表
Data *ProductEventList `json:"Data,omitempty" name:"Data"`
// 唯一请求 ID,每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
RequestId *string `json:"RequestId,omitempty" name:"RequestId"`
}
Predefined struct for user
type EventDetail ¶
type EventDetail struct {
// 产品ID
ProductId *string `json:"ProductId,omitempty" name:"ProductId"`
// 产品名称
ProductName *string `json:"ProductName,omitempty" name:"ProductName"`
// 地域ID,非区域性地域返回non-regional
RegionId *string `json:"RegionId,omitempty" name:"RegionId"`
// 地域名称
RegionName *string `json:"RegionName,omitempty" name:"RegionName"`
// 事件开始时间
StartTime *string `json:"StartTime,omitempty" name:"StartTime"`
// 事件结束时间,当事件正在发生还未结束时,结束时间返回空
EndTime *string `json:"EndTime,omitempty" name:"EndTime"`
// 事件当前状态:提示、异常、正常
CurrentStatus *string `json:"CurrentStatus,omitempty" name:"CurrentStatus"`
}
type ProductEventList ¶
type ProductEventList struct {
// 事件详情列表
// 注意:此字段可能返回 null,表示取不到有效值。
EventList []*EventDetail `json:"EventList,omitempty" name:"EventList"`
}
Click to show internal directories.
Click to hide internal directories.