v20210601

package
v1.0.381 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 7, 2022 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

const (

	// 鉴权失败。
	FAILEDOPERATION_AUTHENTICATIONFAILED = "FailedOperation.AuthenticationFailed"

	// 依赖服务错误。
	FAILEDOPERATION_METACOMPILERERROR = "FailedOperation.MetaCompilerError"

	// 检查运行时失败。
	INTERNALERROR_CHECKRUNTIMEFAILED = "InternalError.CheckRuntimeFailed"

	// 获取运行时应用数量失败。
	INTERNALERROR_COUNTRUNTIMEINSTANCESFAILED = "InternalError.CountRuntimeInstancesFailed"

	// 数据库内部错误。
	INTERNALERROR_DATABASEERROR = "InternalError.DatabaseError"

	// 获取运行时应用列表失败。
	INTERNALERROR_LISTRUNTIMEINSTANCESFAILED = "InternalError.ListRuntimeInstancesFailed"

	// 获取运行时列表失败。
	INTERNALERROR_LISTRUNTIMESFAILED = "InternalError.ListRuntimesFailed"

	// 依赖模块metacompiler错误。
	INTERNALERROR_METACOMPILERERROR = "InternalError.MetaCompilerError"

	// rpc调用异常。
	INTERNALERROR_RPCPILOTSERVERERROR = "InternalError.RpcPilotServerError"

	// 指标查询参数错误。
	INVALIDPARAMETERVALUE_INVALIDRUNTIMEMETRICSEARCHCONDITION = "InvalidParameterValue.InvalidRuntimeMetricSearchCondition"

	// 共享运行时不支持此操作。
	INVALIDPARAMETERVALUE_NOTSUPPORTEDACTIONFORPUBLICRUNTIME = "InvalidParameterValue.NotSupportedActionForPublicRuntime"

	// 不支持的Zone。
	INVALIDPARAMETERVALUE_PILOTZONENOTSUPPORTED = "InvalidParameterValue.PilotZoneNotSupported"

	// 运行时已删除。
	INVALIDPARAMETERVALUE_RUNTIMEALREADYDELETED = "InvalidParameterValue.RuntimeAlreadyDeleted"

	// 运行时不存在。
	INVALIDPARAMETERVALUE_RUNTIMEIDNOTEXIST = "InvalidParameterValue.RuntimeIdNotExist"

	// 当前指标不支持查询百分比。
	INVALIDPARAMETERVALUE_RUNTIMEMETRICRATENOTSUPPORT = "InvalidParameterValue.RuntimeMetricRateNotSupport"

	// 运行时命名空间不合法。
	INVALIDPARAMETERVALUE_RUNTIMENAMESPACEINVALID = "InvalidParameterValue.RuntimeNamespaceInvalid"

	// 运行时地域不存在。
	INVALIDPARAMETERVALUE_RUNTIMEZONENOTEXISTED = "InvalidParameterValue.RuntimeZoneNotExisted"
)
const APIVersion = "2021-06-01"

Variables

This section is empty.

Functions

This section is empty.

Types

type AbstractRuntimeMC

type AbstractRuntimeMC struct {

	// 运行时id
	RuntimeId *int64 `json:"RuntimeId,omitempty" name:"RuntimeId"`

	// 运行时名称,用户输入,同一uin内唯一
	DisplayName *string `json:"DisplayName,omitempty" name:"DisplayName"`

	// 运行时类型:0: sandbox, 1:shared, 2:private
	Type *int64 `json:"Type,omitempty" name:"Type"`

	// 运行时所在地域,tianjin,beijiing,guangzhou等
	Zone *string `json:"Zone,omitempty" name:"Zone"`

	// 运行时所在地域,tianjin,beijiing,guangzhou等(同Zone)
	Area *string `json:"Area,omitempty" name:"Area"`

	// 运行时应用listener地址后缀
	Addr *string `json:"Addr,omitempty" name:"Addr"`
}

type Client

type Client struct {
	common.Client
}

func NewClient

func NewClient(credential common.CredentialIface, region string, clientProfile *profile.ClientProfile) (client *Client, err error)

func NewClientWithSecretId

func NewClientWithSecretId(secretId, secretKey, region string) (client *Client, err error)

Deprecated

func (*Client) GetRuntimeMC

func (c *Client) GetRuntimeMC(request *GetRuntimeMCRequest) (response *GetRuntimeMCResponse, err error)

GetRuntimeMC 获取运行时详情

可能返回的错误码:

FAILEDOPERATION_AUTHENTICATIONFAILED = "FailedOperation.AuthenticationFailed"
INTERNALERROR_CHECKRUNTIMEFAILED = "InternalError.CheckRuntimeFailed"
INTERNALERROR_COUNTRUNTIMEINSTANCESFAILED = "InternalError.CountRuntimeInstancesFailed"
INTERNALERROR_DATABASEERROR = "InternalError.DatabaseError"
INTERNALERROR_METACOMPILERERROR = "InternalError.MetaCompilerError"
INTERNALERROR_RPCPILOTSERVERERROR = "InternalError.RpcPilotServerError"
INVALIDPARAMETERVALUE_PILOTZONENOTSUPPORTED = "InvalidParameterValue.PilotZoneNotSupported"
INVALIDPARAMETERVALUE_RUNTIMEALREADYDELETED = "InvalidParameterValue.RuntimeAlreadyDeleted"
INVALIDPARAMETERVALUE_RUNTIMEIDNOTEXIST = "InvalidParameterValue.RuntimeIdNotExist"
INVALIDPARAMETERVALUE_RUNTIMENAMESPACEINVALID = "InvalidParameterValue.RuntimeNamespaceInvalid"
INVALIDPARAMETERVALUE_RUNTIMEZONENOTEXISTED = "InvalidParameterValue.RuntimeZoneNotExisted"

func (*Client) GetRuntimeMCWithContext added in v1.0.324

func (c *Client) GetRuntimeMCWithContext(ctx context.Context, request *GetRuntimeMCRequest) (response *GetRuntimeMCResponse, err error)

GetRuntimeMC 获取运行时详情

可能返回的错误码:

FAILEDOPERATION_AUTHENTICATIONFAILED = "FailedOperation.AuthenticationFailed"
INTERNALERROR_CHECKRUNTIMEFAILED = "InternalError.CheckRuntimeFailed"
INTERNALERROR_COUNTRUNTIMEINSTANCESFAILED = "InternalError.CountRuntimeInstancesFailed"
INTERNALERROR_DATABASEERROR = "InternalError.DatabaseError"
INTERNALERROR_METACOMPILERERROR = "InternalError.MetaCompilerError"
INTERNALERROR_RPCPILOTSERVERERROR = "InternalError.RpcPilotServerError"
INVALIDPARAMETERVALUE_PILOTZONENOTSUPPORTED = "InvalidParameterValue.PilotZoneNotSupported"
INVALIDPARAMETERVALUE_RUNTIMEALREADYDELETED = "InvalidParameterValue.RuntimeAlreadyDeleted"
INVALIDPARAMETERVALUE_RUNTIMEIDNOTEXIST = "InvalidParameterValue.RuntimeIdNotExist"
INVALIDPARAMETERVALUE_RUNTIMENAMESPACEINVALID = "InvalidParameterValue.RuntimeNamespaceInvalid"
INVALIDPARAMETERVALUE_RUNTIMEZONENOTEXISTED = "InvalidParameterValue.RuntimeZoneNotExisted"

func (*Client) GetRuntimeResourceMonitorMetricMC

func (c *Client) GetRuntimeResourceMonitorMetricMC(request *GetRuntimeResourceMonitorMetricMCRequest) (response *GetRuntimeResourceMonitorMetricMCResponse, err error)

GetRuntimeResourceMonitorMetricMC 获取运行时资源监控详情,cpu,memory,bandwidth

可能返回的错误码:

INTERNALERROR_CHECKRUNTIMEFAILED = "InternalError.CheckRuntimeFailed"
INVALIDPARAMETERVALUE_INVALIDRUNTIMEMETRICSEARCHCONDITION = "InvalidParameterValue.InvalidRuntimeMetricSearchCondition"
INVALIDPARAMETERVALUE_NOTSUPPORTEDACTIONFORPUBLICRUNTIME = "InvalidParameterValue.NotSupportedActionForPublicRuntime"
INVALIDPARAMETERVALUE_PILOTZONENOTSUPPORTED = "InvalidParameterValue.PilotZoneNotSupported"
INVALIDPARAMETERVALUE_RUNTIMEALREADYDELETED = "InvalidParameterValue.RuntimeAlreadyDeleted"
INVALIDPARAMETERVALUE_RUNTIMEIDNOTEXIST = "InvalidParameterValue.RuntimeIdNotExist"
INVALIDPARAMETERVALUE_RUNTIMEMETRICRATENOTSUPPORT = "InvalidParameterValue.RuntimeMetricRateNotSupport"
INVALIDPARAMETERVALUE_RUNTIMENAMESPACEINVALID = "InvalidParameterValue.RuntimeNamespaceInvalid"
INVALIDPARAMETERVALUE_RUNTIMEZONENOTEXISTED = "InvalidParameterValue.RuntimeZoneNotExisted"

func (*Client) GetRuntimeResourceMonitorMetricMCWithContext added in v1.0.324

func (c *Client) GetRuntimeResourceMonitorMetricMCWithContext(ctx context.Context, request *GetRuntimeResourceMonitorMetricMCRequest) (response *GetRuntimeResourceMonitorMetricMCResponse, err error)

GetRuntimeResourceMonitorMetricMC 获取运行时资源监控详情,cpu,memory,bandwidth

可能返回的错误码:

INTERNALERROR_CHECKRUNTIMEFAILED = "InternalError.CheckRuntimeFailed"
INVALIDPARAMETERVALUE_INVALIDRUNTIMEMETRICSEARCHCONDITION = "InvalidParameterValue.InvalidRuntimeMetricSearchCondition"
INVALIDPARAMETERVALUE_NOTSUPPORTEDACTIONFORPUBLICRUNTIME = "InvalidParameterValue.NotSupportedActionForPublicRuntime"
INVALIDPARAMETERVALUE_PILOTZONENOTSUPPORTED = "InvalidParameterValue.PilotZoneNotSupported"
INVALIDPARAMETERVALUE_RUNTIMEALREADYDELETED = "InvalidParameterValue.RuntimeAlreadyDeleted"
INVALIDPARAMETERVALUE_RUNTIMEIDNOTEXIST = "InvalidParameterValue.RuntimeIdNotExist"
INVALIDPARAMETERVALUE_RUNTIMEMETRICRATENOTSUPPORT = "InvalidParameterValue.RuntimeMetricRateNotSupport"
INVALIDPARAMETERVALUE_RUNTIMENAMESPACEINVALID = "InvalidParameterValue.RuntimeNamespaceInvalid"
INVALIDPARAMETERVALUE_RUNTIMEZONENOTEXISTED = "InvalidParameterValue.RuntimeZoneNotExisted"

func (*Client) ListDeployableRuntimesMC

func (c *Client) ListDeployableRuntimesMC(request *ListDeployableRuntimesMCRequest) (response *ListDeployableRuntimesMCResponse, err error)

ListDeployableRuntimesMC 返回用户可用的运行时列表,发布应用时返回的运行时环境,仅shared和private运行时,无sandbox运行时,并且只有running/scaling状态的

可能返回的错误码:

FAILEDOPERATION_AUTHENTICATIONFAILED = "FailedOperation.AuthenticationFailed"
INTERNALERROR_DATABASEERROR = "InternalError.DatabaseError"

func (*Client) ListDeployableRuntimesMCWithContext added in v1.0.324

func (c *Client) ListDeployableRuntimesMCWithContext(ctx context.Context, request *ListDeployableRuntimesMCRequest) (response *ListDeployableRuntimesMCResponse, err error)

ListDeployableRuntimesMC 返回用户可用的运行时列表,发布应用时返回的运行时环境,仅shared和private运行时,无sandbox运行时,并且只有running/scaling状态的

可能返回的错误码:

FAILEDOPERATION_AUTHENTICATIONFAILED = "FailedOperation.AuthenticationFailed"
INTERNALERROR_DATABASEERROR = "InternalError.DatabaseError"

func (*Client) ListRuntimeDeployedInstancesMC

func (c *Client) ListRuntimeDeployedInstancesMC(request *ListRuntimeDeployedInstancesMCRequest) (response *ListRuntimeDeployedInstancesMCResponse, err error)

ListRuntimeDeployedInstancesMC 获取运行时部署的应用实例列表

可能返回的错误码:

INTERNALERROR_CHECKRUNTIMEFAILED = "InternalError.CheckRuntimeFailed"
INTERNALERROR_DATABASEERROR = "InternalError.DatabaseError"
INTERNALERROR_LISTRUNTIMEINSTANCESFAILED = "InternalError.ListRuntimeInstancesFailed"
INTERNALERROR_METACOMPILERERROR = "InternalError.MetaCompilerError"
INTERNALERROR_RPCPILOTSERVERERROR = "InternalError.RpcPilotServerError"
INVALIDPARAMETERVALUE_PILOTZONENOTSUPPORTED = "InvalidParameterValue.PilotZoneNotSupported"
INVALIDPARAMETERVALUE_RUNTIMEALREADYDELETED = "InvalidParameterValue.RuntimeAlreadyDeleted"
INVALIDPARAMETERVALUE_RUNTIMEIDNOTEXIST = "InvalidParameterValue.RuntimeIdNotExist"
INVALIDPARAMETERVALUE_RUNTIMEZONENOTEXISTED = "InvalidParameterValue.RuntimeZoneNotExisted"

func (*Client) ListRuntimeDeployedInstancesMCWithContext added in v1.0.324

func (c *Client) ListRuntimeDeployedInstancesMCWithContext(ctx context.Context, request *ListRuntimeDeployedInstancesMCRequest) (response *ListRuntimeDeployedInstancesMCResponse, err error)

ListRuntimeDeployedInstancesMC 获取运行时部署的应用实例列表

可能返回的错误码:

INTERNALERROR_CHECKRUNTIMEFAILED = "InternalError.CheckRuntimeFailed"
INTERNALERROR_DATABASEERROR = "InternalError.DatabaseError"
INTERNALERROR_LISTRUNTIMEINSTANCESFAILED = "InternalError.ListRuntimeInstancesFailed"
INTERNALERROR_METACOMPILERERROR = "InternalError.MetaCompilerError"
INTERNALERROR_RPCPILOTSERVERERROR = "InternalError.RpcPilotServerError"
INVALIDPARAMETERVALUE_PILOTZONENOTSUPPORTED = "InvalidParameterValue.PilotZoneNotSupported"
INVALIDPARAMETERVALUE_RUNTIMEALREADYDELETED = "InvalidParameterValue.RuntimeAlreadyDeleted"
INVALIDPARAMETERVALUE_RUNTIMEIDNOTEXIST = "InvalidParameterValue.RuntimeIdNotExist"
INVALIDPARAMETERVALUE_RUNTIMEZONENOTEXISTED = "InvalidParameterValue.RuntimeZoneNotExisted"

func (*Client) ListRuntimesMC

func (c *Client) ListRuntimesMC(request *ListRuntimesMCRequest) (response *ListRuntimesMCResponse, err error)

ListRuntimesMC 返回用户的运行时列表,运行时管理主页使用,包含沙箱、共享运行时及独立运行时环境,不包含已经删除的运行时

可能返回的错误码:

FAILEDOPERATION_AUTHENTICATIONFAILED = "FailedOperation.AuthenticationFailed"
FAILEDOPERATION_METACOMPILERERROR = "FailedOperation.MetaCompilerError"
INTERNALERROR_DATABASEERROR = "InternalError.DatabaseError"
INTERNALERROR_LISTRUNTIMESFAILED = "InternalError.ListRuntimesFailed"
INTERNALERROR_METACOMPILERERROR = "InternalError.MetaCompilerError"
INTERNALERROR_RPCPILOTSERVERERROR = "InternalError.RpcPilotServerError"

func (*Client) ListRuntimesMCWithContext added in v1.0.324

func (c *Client) ListRuntimesMCWithContext(ctx context.Context, request *ListRuntimesMCRequest) (response *ListRuntimesMCResponse, err error)

ListRuntimesMC 返回用户的运行时列表,运行时管理主页使用,包含沙箱、共享运行时及独立运行时环境,不包含已经删除的运行时

可能返回的错误码:

FAILEDOPERATION_AUTHENTICATIONFAILED = "FailedOperation.AuthenticationFailed"
FAILEDOPERATION_METACOMPILERERROR = "FailedOperation.MetaCompilerError"
INTERNALERROR_DATABASEERROR = "InternalError.DatabaseError"
INTERNALERROR_LISTRUNTIMESFAILED = "InternalError.ListRuntimesFailed"
INTERNALERROR_METACOMPILERERROR = "InternalError.MetaCompilerError"
INTERNALERROR_RPCPILOTSERVERERROR = "InternalError.RpcPilotServerError"

type GetRuntimeMCRequest

type GetRuntimeMCRequest struct {
	*tchttp.BaseRequest

	// 运行时id
	RuntimeId *int64 `json:"RuntimeId,omitempty" name:"RuntimeId"`

	// 运行时地域
	Zone *string `json:"Zone,omitempty" name:"Zone"`
}

func NewGetRuntimeMCRequest

func NewGetRuntimeMCRequest() (request *GetRuntimeMCRequest)

func (*GetRuntimeMCRequest) FromJsonString

func (r *GetRuntimeMCRequest) FromJsonString(s string) error

FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check

func (*GetRuntimeMCRequest) ToJsonString

func (r *GetRuntimeMCRequest) ToJsonString() string

type GetRuntimeMCResponse

type GetRuntimeMCResponse struct {
	*tchttp.BaseResponse
	Response *struct {

		// 运行时详情
		Runtime *RuntimeMC `json:"Runtime,omitempty" name:"Runtime"`

		// 唯一请求 ID,每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
		RequestId *string `json:"RequestId,omitempty" name:"RequestId"`
	} `json:"Response"`
}

func NewGetRuntimeMCResponse

func NewGetRuntimeMCResponse() (response *GetRuntimeMCResponse)

func (*GetRuntimeMCResponse) FromJsonString

func (r *GetRuntimeMCResponse) FromJsonString(s string) error

FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check

func (*GetRuntimeMCResponse) ToJsonString

func (r *GetRuntimeMCResponse) ToJsonString() string

type GetRuntimeResourceMonitorMetricMCRequest

type GetRuntimeResourceMonitorMetricMCRequest struct {
	*tchttp.BaseRequest

	// 运行时id
	RuntimeId *int64 `json:"RuntimeId,omitempty" name:"RuntimeId"`

	// 起始时间
	StartTime *int64 `json:"StartTime,omitempty" name:"StartTime"`

	// 结束时间
	EndTime *int64 `json:"EndTime,omitempty" name:"EndTime"`

	// 指标类型:0:CPU, 1:MemUsageBytes, 2:K8sWorkloadNetworkReceiveBytesBw, 3:K8sWorkloadNetworkTransmitBytesBw
	MetricType *int64 `json:"MetricType,omitempty" name:"MetricType"`

	// 是否返回百分比数值,仅支持CPU,Memory
	RateType *bool `json:"RateType,omitempty" name:"RateType"`

	// 采样粒度:60(s), 300(s), 3600(s), 86400(s)
	Interval *int64 `json:"Interval,omitempty" name:"Interval"`
}

func NewGetRuntimeResourceMonitorMetricMCRequest

func NewGetRuntimeResourceMonitorMetricMCRequest() (request *GetRuntimeResourceMonitorMetricMCRequest)

func (*GetRuntimeResourceMonitorMetricMCRequest) FromJsonString

FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check

func (*GetRuntimeResourceMonitorMetricMCRequest) ToJsonString

type GetRuntimeResourceMonitorMetricMCResponse

type GetRuntimeResourceMonitorMetricMCResponse struct {
	*tchttp.BaseResponse
	Response *struct {

		// 指标名称,K8sWorkloadCpuCoreUsed,K8sWorkloadMemUsageBytes,K8sWorkloadNetworkReceiveBytesBw,K8sWorkloadNetworkTransmitBytesBw
		MetricType *string `json:"MetricType,omitempty" name:"MetricType"`

		// metric数值列表
		Values []*MetricValueMC `json:"Values,omitempty" name:"Values"`

		// 唯一请求 ID,每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
		RequestId *string `json:"RequestId,omitempty" name:"RequestId"`
	} `json:"Response"`
}

func NewGetRuntimeResourceMonitorMetricMCResponse

func NewGetRuntimeResourceMonitorMetricMCResponse() (response *GetRuntimeResourceMonitorMetricMCResponse)

func (*GetRuntimeResourceMonitorMetricMCResponse) FromJsonString

FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check

func (*GetRuntimeResourceMonitorMetricMCResponse) ToJsonString

type ListDeployableRuntimesMCRequest

type ListDeployableRuntimesMCRequest struct {
	*tchttp.BaseRequest
}

func NewListDeployableRuntimesMCRequest

func NewListDeployableRuntimesMCRequest() (request *ListDeployableRuntimesMCRequest)

func (*ListDeployableRuntimesMCRequest) FromJsonString

func (r *ListDeployableRuntimesMCRequest) FromJsonString(s string) error

FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check

func (*ListDeployableRuntimesMCRequest) ToJsonString

func (r *ListDeployableRuntimesMCRequest) ToJsonString() string

type ListDeployableRuntimesMCResponse

type ListDeployableRuntimesMCResponse struct {
	*tchttp.BaseResponse
	Response *struct {

		// 运行时列表
		Runtimes []*AbstractRuntimeMC `json:"Runtimes,omitempty" name:"Runtimes"`

		// 唯一请求 ID,每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
		RequestId *string `json:"RequestId,omitempty" name:"RequestId"`
	} `json:"Response"`
}

func NewListDeployableRuntimesMCResponse

func NewListDeployableRuntimesMCResponse() (response *ListDeployableRuntimesMCResponse)

func (*ListDeployableRuntimesMCResponse) FromJsonString

func (r *ListDeployableRuntimesMCResponse) FromJsonString(s string) error

FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check

func (*ListDeployableRuntimesMCResponse) ToJsonString

func (r *ListDeployableRuntimesMCResponse) ToJsonString() string

type ListRuntimeDeployedInstancesMCRequest

type ListRuntimeDeployedInstancesMCRequest struct {
	*tchttp.BaseRequest

	// 运行时id
	RuntimeId *int64 `json:"RuntimeId,omitempty" name:"RuntimeId"`

	// 最大请求数量
	Limit *int64 `json:"Limit,omitempty" name:"Limit"`

	// 请求偏移量
	Offset *int64 `json:"Offset,omitempty" name:"Offset"`

	// 排序类型:1:创建时间排序, 2:更新时间排序(默认)
	SortType *int64 `json:"SortType,omitempty" name:"SortType"`

	// 排序方式:asc,desc(默认)
	Sort *string `json:"Sort,omitempty" name:"Sort"`

	// 运行时地域
	Zone *string `json:"Zone,omitempty" name:"Zone"`
}

func NewListRuntimeDeployedInstancesMCRequest

func NewListRuntimeDeployedInstancesMCRequest() (request *ListRuntimeDeployedInstancesMCRequest)

func (*ListRuntimeDeployedInstancesMCRequest) FromJsonString

func (r *ListRuntimeDeployedInstancesMCRequest) FromJsonString(s string) error

FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check

func (*ListRuntimeDeployedInstancesMCRequest) ToJsonString

type ListRuntimeDeployedInstancesMCResponse

type ListRuntimeDeployedInstancesMCResponse struct {
	*tchttp.BaseResponse
	Response *struct {

		// 运行时所部属的应用实例列表
		Instances []*RuntimeDeployedInstanceMC `json:"Instances,omitempty" name:"Instances"`

		// 满足条件的记录总数,用于分页器
		TotalCount *int64 `json:"TotalCount,omitempty" name:"TotalCount"`

		// 唯一请求 ID,每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
		RequestId *string `json:"RequestId,omitempty" name:"RequestId"`
	} `json:"Response"`
}

func NewListRuntimeDeployedInstancesMCResponse

func NewListRuntimeDeployedInstancesMCResponse() (response *ListRuntimeDeployedInstancesMCResponse)

func (*ListRuntimeDeployedInstancesMCResponse) FromJsonString

FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check

func (*ListRuntimeDeployedInstancesMCResponse) ToJsonString

type ListRuntimesMCRequest

type ListRuntimesMCRequest struct {
	*tchttp.BaseRequest
}

func NewListRuntimesMCRequest

func NewListRuntimesMCRequest() (request *ListRuntimesMCRequest)

func (*ListRuntimesMCRequest) FromJsonString

func (r *ListRuntimesMCRequest) FromJsonString(s string) error

FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check

func (*ListRuntimesMCRequest) ToJsonString

func (r *ListRuntimesMCRequest) ToJsonString() string

type ListRuntimesMCResponse

type ListRuntimesMCResponse struct {
	*tchttp.BaseResponse
	Response *struct {

		// 运行时列表
		Runtimes []*RuntimeMC `json:"Runtimes,omitempty" name:"Runtimes"`

		// 唯一请求 ID,每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
		RequestId *string `json:"RequestId,omitempty" name:"RequestId"`
	} `json:"Response"`
}

func NewListRuntimesMCResponse

func NewListRuntimesMCResponse() (response *ListRuntimesMCResponse)

func (*ListRuntimesMCResponse) FromJsonString

func (r *ListRuntimesMCResponse) FromJsonString(s string) error

FromJsonString It is highly **NOT** recommended to use this function because it has no param check, nor strict type check

func (*ListRuntimesMCResponse) ToJsonString

func (r *ListRuntimesMCResponse) ToJsonString() string

type MetricValueMC

type MetricValueMC struct {

	// 时间
	// 注意:此字段可能返回 null,表示取不到有效值。
	Time *int64 `json:"Time,omitempty" name:"Time"`

	// 对应的value值
	// 注意:此字段可能返回 null,表示取不到有效值。
	Val *string `json:"Val,omitempty" name:"Val"`
}

type RuntimeDeployedInstanceMC

type RuntimeDeployedInstanceMC struct {

	// 项目id
	GroupId *int64 `json:"GroupId,omitempty" name:"GroupId"`

	// 项目名称
	GroupName *string `json:"GroupName,omitempty" name:"GroupName"`

	// 应用id
	ProjectId *int64 `json:"ProjectId,omitempty" name:"ProjectId"`

	// 应用名称
	ProjectName *string `json:"ProjectName,omitempty" name:"ProjectName"`

	// 应用实例id
	InstanceId *int64 `json:"InstanceId,omitempty" name:"InstanceId"`

	// 应用实例版本
	InstanceVersion *int64 `json:"InstanceVersion,omitempty" name:"InstanceVersion"`

	// 应用实例创建时间
	InstanceCreatedAt *int64 `json:"InstanceCreatedAt,omitempty" name:"InstanceCreatedAt"`

	// 应用实例部署状态. 0:running, 1:deleting
	Status *int64 `json:"Status,omitempty" name:"Status"`

	// 应用实例部署创建时间
	CreatedAt *int64 `json:"CreatedAt,omitempty" name:"CreatedAt"`

	// 应用实例部署更新时间
	UpdatedAt *int64 `json:"UpdatedAt,omitempty" name:"UpdatedAt"`

	// 应用类型:0:NormalApp普通应用 1:TemplateApp模板应用 2:LightApp轻应用 3:MicroConnTemplate微连接模板 4:MicroConnApp微连接应用
	ProjectType *int64 `json:"ProjectType,omitempty" name:"ProjectType"`
}

type RuntimeMC

type RuntimeMC struct {

	// 运行时id
	RuntimeId *int64 `json:"RuntimeId,omitempty" name:"RuntimeId"`

	// 主账号uin
	Uin *string `json:"Uin,omitempty" name:"Uin"`

	// 运行时名称,用户输入,同一uin内唯一
	DisplayName *string `json:"DisplayName,omitempty" name:"DisplayName"`

	// 运行时所在地域,tianjin,beijiing,guangzhou等
	Zone *string `json:"Zone,omitempty" name:"Zone"`

	// 运行时类型:0: sandbox, 1:shared, 2:private
	Type *int64 `json:"Type,omitempty" name:"Type"`

	// 运行时状态:1:running, 2:deleting, 3:creating, 4:scaling, 5:unavailable, 6:deleted, 7:errored
	Status *int64 `json:"Status,omitempty" name:"Status"`

	// 运行时创建时间
	CreatedAt *int64 `json:"CreatedAt,omitempty" name:"CreatedAt"`

	// 运行时更新时间
	UpdatedAt *int64 `json:"UpdatedAt,omitempty" name:"UpdatedAt"`

	// 运行时资源配置,worker总配额,0:0vCore0G, 1:1vCore2G, 2:2vCore4G, 4:4vCore8G, 8:8vCore16G, 12:12vCore24G, 16:16vCore32G, 100:unlimited
	WorkerSize *int64 `json:"WorkerSize,omitempty" name:"WorkerSize"`

	// 运行时资源配置,worker副本数
	WorkerReplica *int64 `json:"WorkerReplica,omitempty" name:"WorkerReplica"`

	// 正在运行的应用实例数量
	RunningInstanceCount *int64 `json:"RunningInstanceCount,omitempty" name:"RunningInstanceCount"`

	// 已使用cpu核数
	CpuUsed *float64 `json:"CpuUsed,omitempty" name:"CpuUsed"`

	// cpu核数上限
	CpuLimit *float64 `json:"CpuLimit,omitempty" name:"CpuLimit"`

	// 已使用内存 MB
	MemoryUsed *float64 `json:"MemoryUsed,omitempty" name:"MemoryUsed"`

	// 内存上限 MB
	MemoryLimit *float64 `json:"MemoryLimit,omitempty" name:"MemoryLimit"`
}

Jump to